<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

if ( ! function_exists( 'onjob_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since  Onjob Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function onjob_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'onjob_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'onjob_pro_is_static_homepage_enable' ) ) :
	/**
	 * Check if static homepage is enabled.
	 *
	 * @since Onjob Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function onjob_pro_is_static_homepage_enable( $control ) {
		return ( 'page' == $control->manager->get_setting( 'show_on_front' )->value() );
	}
endif;

if ( ! function_exists( 'onjob_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since  Onjob Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function onjob_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'onjob_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'onjob_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since  Onjob Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function onjob_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'onjob_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if slider section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[slider_content_type]' )->value();
	return onjob_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[slider_content_type]' )->value();
	return onjob_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[slider_content_type]' )->value();
	return onjob_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if slider separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_slider_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[slider_content_type]' )->value();
    return onjob_pro_is_slider_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if search section is enabled.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_search_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[search_section_enable]' )->value() );
}

/**
 * Check if search section content type is page.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_search_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_search_content_type' )->value();
	return onjob_pro_is_search_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is post.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_search_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_search_content_type' )->value();
	return onjob_pro_is_search_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if search section content type is custom.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_if_search_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_search_content_type' )->value();
	return onjob_pro_is_search_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if service section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[service_content_type]' )->value();
	return onjob_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[service_content_type]' )->value();
	return onjob_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[service_content_type]' )->value();
	return onjob_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_service_section_hr_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[service_content_type]' )->value();
	return onjob_pro_is_service_section_enable( $control ) && ( 'category' != $content_type);
}

/**
 * Check if testimonial section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_testimonial_section_enable( $control ) {
    return ( $control->manager->get_setting( 'onjob_pro_theme_options[testimonial_section_enable]' )->value() );
}
/**
 * Check if testimonial section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_testimonial_section_content_page_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[testimonial_content_type]' )->value();
    return onjob_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if testimonial section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_testimonial_section_content_post_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[testimonial_content_type]' )->value();
    return onjob_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if testimonial section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_testimonial_section_content_category_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[testimonial_content_type]' )->value();
    return onjob_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[blog_content_type]' )->value();
	return onjob_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[blog_content_type]' )->value();
	return onjob_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[blog_content_type]' )->value();
	return onjob_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[blog_content_type]' )->value();
	return onjob_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if blog separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_blog_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[blog_content_type]' )->value();
    return onjob_pro_is_blog_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if team section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_team_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[team_section_enable]' )->value() );
}


/**
 * Check if team section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_team_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[team_content_type]' )->value();
	return onjob_pro_is_team_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if team section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_team_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[team_content_type]' )->value();
	return onjob_pro_is_team_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if team section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_team_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[team_content_type]' )->value();
	return onjob_pro_is_team_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if team section content type is custom.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_team_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[team_content_type]' )->value();
	return onjob_pro_is_team_section_enable( $control ) && ( 'custom' == $content_type );
}


/**
 * Check if counter section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if Promotion section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_promotion_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[promotion_section_enable]' )->value() );
}

/**
 * Check if Promotion section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_promotion_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[promotion_content_type]' )->value();
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[promotion_section_enable]' )->value() && ('post' == $content_type) );
}
/**
 * Check if Promotion section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_promotion_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[promotion_content_type]' )->value();
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[promotion_section_enable]' )->value() && ('page' == $content_type) );
}


/**
 * Check if gallery section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[gallery_content_type]' )->value();
	return onjob_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[gallery_content_type]' )->value();
	return onjob_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[gallery_content_type]' )->value();
	return onjob_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if gallery section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[gallery_content_type]' )->value();
	return onjob_pro_is_gallery_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if gallery separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_gallery_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[gallery_content_type]' )->value();
    return onjob_pro_is_gallery_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if sponsor section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_section_enable]' )->value() );
}

/**
 * Check if sponsor section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_content_type]' )->value();
	return onjob_pro_is_sponsor_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if sponsor section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_content_type]' )->value();
	return onjob_pro_is_sponsor_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if sponsor section content type is custom.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_content_type]' )->value();
	return onjob_pro_is_sponsor_section_enable( $control ) && ( 'custom' == $content_type );
}
/**
 * Check if sponsor section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_content_type]' )->value();
	return onjob_pro_is_sponsor_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if sponsor separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_sponsor_section_separator_enable( $control ) {

    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[sponsor_content_type]' )->value();
    return onjob_pro_is_sponsor_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if featured_post section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[featured_post_section_enable]' )->value() );
}

/**
 * Check if featured_post section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_post_content_type]' )->value();
	return onjob_pro_is_featured_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_post section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_post_content_type]' )->value();
	return onjob_pro_is_featured_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_post section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_post_content_type]' )->value();
	return onjob_pro_is_featured_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_post separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_post_section_content_seperator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_post_content_type]' )->value();
    return onjob_pro_is_featured_post_section_enable( $control ) && !( 'category' == $content_type ) ;
}

/**
 * Check if most_viewed section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_section_enable]' )->value() );
}

/**
 * Check if most_viewed section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_content_type]' )->value();
	return onjob_pro_is_most_viewed_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if most_viewed section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_content_type]' )->value();
	return onjob_pro_is_most_viewed_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if most_viewed section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_content_type]' )->value();
	return onjob_pro_is_most_viewed_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if most_viewed section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_content_type]' )->value();
	return onjob_pro_is_most_viewed_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if most_viewed separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_most_viewed_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[most_viewed_content_type]' )->value();
    return onjob_pro_is_most_viewed_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}


/**
 * Check if recent_job section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_section_enable]' )->value() );
}

/**
 * Check if recent_job section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
	return onjob_pro_is_recent_job_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent_job section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
	return onjob_pro_is_recent_job_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent_job section content type is job_listing.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_job_listing_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
	return onjob_pro_is_recent_job_section_enable( $control ) && ( 'job_listing' == $content_type );
}

/**
 * Check if recent_job section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
	return onjob_pro_is_recent_job_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if recent_job section content type is job_listing_category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_job_listing_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
	return onjob_pro_is_recent_job_section_enable( $control ) && ( 'job_listing_category' == $content_type );
}

/**
 * Check if recent_job separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_job_section_content_seperator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_job_content_type]' )->value();
    return onjob_pro_is_recent_job_section_enable( $control ) && !( 'category' == $content_type || 'job_listing_category' == $content_type ) ;
}
/**
 * Check if subscription section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if video section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if latest_post section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_section_enable]' )->value() );
}

/**
 * Check if latest_post section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_content_type]' )->value();
	return onjob_pro_is_latest_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest_post section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_content_type]' )->value();
	return onjob_pro_is_latest_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if latest_post section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_content_type]' )->value();
	return onjob_pro_is_latest_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest_post section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_content_type]' )->value();
	return onjob_pro_is_latest_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if latest_post separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_latest_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[latest_post_content_type]' )->value();
    return onjob_pro_is_latest_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if course section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[course_content_type]' )->value();
	return onjob_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[course_content_type]' )->value();
	return onjob_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[course_content_type]' )->value();
	return onjob_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if course separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_course_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[course_content_type]' )->value();
    return onjob_pro_is_course_section_enable( $control ) && !( 'category' == $content_type );
}

/**
 * Check if featured_job section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_section_enable]' )->value() );
}

/**
 * Check if featured_job section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_content_type]' )->value();
	return onjob_pro_is_featured_job_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_job section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_content_type]' )->value();
	return onjob_pro_is_featured_job_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if featured_job section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_content_type]' )->value();
	return onjob_pro_is_featured_job_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_job section content type is job job_listing_category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_content_job_listing_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_content_type]' )->value();
	return onjob_pro_is_featured_job_section_enable( $control ) && ( 'job_listing_category' == $content_type );
}

/**
 * Check if featured_job section content type is job job_listing.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_featured_job_section_content_job_listing_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[featured_job_content_type]' )->value();
	return onjob_pro_is_featured_job_section_enable( $control ) && ( 'job_listing' == $content_type );
}


/**
 * Check if company_profile section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_section_enable]' )->value() );
}

/**
 * Check if company_profile section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
	return onjob_pro_is_company_profile_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if company_profile section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
	return onjob_pro_is_company_profile_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if company_profile section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
	return onjob_pro_is_company_profile_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if company_profile section content type is job_listing.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_job_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
	return onjob_pro_is_company_profile_section_enable( $control ) && ( 'job_listing' == $content_type );
}

/**
 * Check if company_profile section content type is job_listing_category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_job_listing_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
	return onjob_pro_is_company_profile_section_enable( $control ) && ( 'job_listing_category' == $content_type );
}
/**
 * Check if company_profile separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_company_profile_section_content_seperator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[company_profile_content_type]' )->value();
    return onjob_pro_is_company_profile_section_enable( $control ) && !( 'category' == $content_type ||  'job_listing_category' == $content_type );
}

/**
 * Check if recent_products section is enabled.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_products_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[recent_products_section_enable]' )->value() );
}

/**
 * Check if recent_products section content type is product.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_products_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_products_content_type]' )->value();
	return onjob_pro_is_recent_products_section_enable( $control ) && ( 'product' == $content_type );
}

/**
 * Check if recent_products section content type is product-category.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_products_section_content_product_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_products_content_type]' )->value();
	return onjob_pro_is_recent_products_section_enable( $control ) && ( 'product-category' == $content_type );
}

/**
 * Check if recent_products separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_recent_products_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[recent_products_content_type]' )->value();
    return onjob_pro_is_recent_products_section_enable( $control ) && !( 'product-category' == $content_type ) ;
}

/**
 * Check if magazine_popular_post section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_section_enable]' )->value() );
}

/**
 * Check if magazine_popular_post section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return onjob_pro_is_magazine_popular_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return onjob_pro_is_magazine_popular_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return onjob_pro_is_magazine_popular_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_popular_post section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_content_type]' )->value();
	return onjob_pro_is_magazine_popular_post_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if magazine_popular_post separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_popular_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_popular_post_content_type]' )->value();
    return onjob_pro_is_magazine_popular_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if magazine_recent_post section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_section_enable]' )->value() );
}

/**
 * Check if magazine_recent_post section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return onjob_pro_is_magazine_recent_post_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return onjob_pro_is_magazine_recent_post_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return onjob_pro_is_magazine_recent_post_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_recent_post section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_content_type]' )->value();
	return onjob_pro_is_magazine_recent_post_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_recent_post separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_recent_post_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_recent_post_content_type]' )->value();
    return onjob_pro_is_magazine_recent_post_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if magazine_sport_news section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_section_enable]' )->value() );
}

/**
 * Check if magazine_sport_news section content type is post.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return onjob_pro_is_magazine_sport_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is page.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return onjob_pro_is_magazine_sport_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is category.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return onjob_pro_is_magazine_sport_news_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if magazine_sport_news section content type is recent.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]' )->value();
	return onjob_pro_is_magazine_sport_news_section_enable( $control ) && ( 'recent' == $content_type );
}
/**
 * Check if magazine_sport_news separator section is enabled.
 *
 * @since  Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_magazine_sport_news_section_separator_enable( $control ) {
    $content_type = $control->manager->get_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]' )->value();
    return onjob_pro_is_magazine_sport_news_section_enable( $control ) && !( 'recent' == $content_type || 'category' == $content_type ) ;
}

/**
 * Check if about section is enabled.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is page.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_about_content_type' )->value();
	return onjob_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}
/**
 * Check if slider section content type is post.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_about_content_type' )->value();
	return onjob_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}
/**
 * Check if slider section content type is custom.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_about_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_about_content_type' )->value();
	return onjob_pro_is_about_section_enable( $control ) && ( 'category' == $content_type );
}
/**
 * Check if about section content type is custom.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_if_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'onjob_pro_theme_options_about_content_type' )->value();
	return onjob_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if footer search is enable.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_footer_search_enable( $control ) {
	return ( $control->manager->get_setting( 'onjob_pro_theme_options[enable_footer_search]' )->value() );
}

/**
 * Check if section is enabled in pro design.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_pro_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'onjob_pro_theme_options[home_layout]' )->value();
	return ( $home_layout == 'pro-design' ||  $home_layout == 'default-design');
}

/**
 * Check if section is enabled in second design.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_second_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'onjob_pro_theme_options[home_layout]' )->value();
	return ( !in_array($home_layout, array('pro-design', 'fourth-design')));
}

/**
 * Check if section is enabled in third design.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_third_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'onjob_pro_theme_options[home_layout]' )->value();
	return ( $home_layout == 'default-design' ||  $home_layout == 'third-design');
}

/**
 * Check if section is enabled in fourth design.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_fourth_design_enable( $control ) {
	$home_layout = $control->manager->get_setting( 'onjob_pro_theme_options[home_layout]' )->value();
	return ( $home_layout == 'fourth-design' ||  $home_layout == 'default-design' );
}

/**
 * Check if section is enabled in fourth design.
 *
 * @since Onjob Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function onjob_pro_is_fourth_design_disable( $control ) {
	$home_layout = $control->manager->get_setting( 'onjob_pro_theme_options[home_layout]' )->value();
	return ( $home_layout != 'fourth-design');
}