<?php
/**
 *  Onjob Pro Customizer.
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function onjob_pro_customize_register( $wp_customize ) {
	$options = onjob_pro_get_theme_options();

	// Load custom control functions.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callback.php';

	// Load partial callback functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport  = 'postMessage';

	// Remove the core header textcolor control, as it shares the main text color.
	$wp_customize->remove_control( 'header_textcolor' );

	// Header title color setting and control.
	$wp_customize->add_setting( 'onjob_pro_theme_options[header_title_color]',
		array(
			'default'           => $options['header_title_color'],
			'sanitize_callback' => 'sanitize_hex_color',
			'transport'			=> 'postMessage'
		)
	);

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize,
		'onjob_pro_theme_options[header_title_color]',
			array(
				'priority'			=> 5,
				'label'             => esc_html__( 'Site Title Color', 'onjob-pro' ),
				'section'           => 'colors',
			)
		)
	);

	// Header tagline color setting and control.
	$wp_customize->add_setting( 'onjob_pro_theme_options[header_tagline_color]',
		array(
			'default'           => $options['header_tagline_color'],
			'sanitize_callback' => 'sanitize_hex_color',
			'transport'			=> 'postMessage'
		)
	);

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize,
		'onjob_pro_theme_options[header_tagline_color]',
			array(
				'priority'			=> 6,
				'label'             => esc_html__( 'Site Tagline Color', 'onjob-pro' ),
				'section'           => 'colors',
			)
		)
	);

	// Site identity extra options.
	$wp_customize->add_setting( 'onjob_pro_theme_options[header_txt_logo_extra]',
		array(
			'default'           => $options['header_txt_logo_extra'],
			'sanitize_callback' => 'onjob_pro_sanitize_select',
			'transport'			=> 'refresh'
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[header_txt_logo_extra]',
		array(
			'priority'			=> 50,
			'type'				=> 'radio',
			'label'             => esc_html__( 'Site Identity Extra Options', 'onjob-pro' ),
			'section'           => 'title_tagline',
			'choices'			=> array( 
				'hide-all'     => esc_html__( 'Hide All', 'onjob-pro' ),
				'show-all'     => esc_html__( 'Show All', 'onjob-pro' ),
				'title-only'   => esc_html__( 'Title Only', 'onjob-pro' ),
				'tagline-only' => esc_html__( 'Tagline Only', 'onjob-pro' ),
				'logo-title'   => esc_html__( 'Logo + Title', 'onjob-pro' ),
				'logo-tagline' => esc_html__( 'Logo + Tagline', 'onjob-pro' ),
			)
		)
	);

	//theme version
	$wp_customize->add_setting( 'onjob_pro_theme_options[theme_version]',
		array(
			'default'           => $options['theme_version'],
			'sanitize_callback' => 'onjob_pro_sanitize_select',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[theme_version]',
		array(
			'type'    	=> 'radio',
			'label'    	=> esc_html__( 'Theme Version', 'onjob-pro' ),
			'section'  	=> 'colors',
			'choices'  	=> array(
				'lite-version'   	=> esc_html__( 'Lite Version', 'onjob-pro' ),
				'dark-version'      => esc_html__( 'Dark Version', 'onjob-pro' ),
			),
		)
	);

	/**
	 * Custom colors.
	 */
	$wp_customize->add_setting( 'onjob_pro_theme_options[colorscheme]',
		array(
			'default'           => $options['colorscheme'],
			'sanitize_callback' => 'onjob_pro_sanitize_select',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[colorscheme]',
		array(
			'type'    => 'radio',
			'label'    => esc_html__( 'Color Scheme', 'onjob-pro' ),
			'section'  => 'colors',
			'choices'  => array(
				'default'   => esc_html__( 'Default', 'onjob-pro' ),
				'green'    => esc_html__( 'Green', 'onjob-pro' ),
				'blue'     => esc_html__( 'BLue', 'onjob-pro' ),
				'yellow'   => esc_html__( 'Yellow', 'onjob-pro' ),
				'red'      => esc_html__( 'Red', 'onjob-pro' ),
				'custom'   => esc_html__( 'Custom', 'onjob-pro' ),
			),
		)
	);

	$wp_customize->add_setting( 'onjob_pro_theme_options[colorscheme_hue]',
		array(
			'default'           => $options['colorscheme_hue'],
			'sanitize_callback' => 'sanitize_hex_color', // The hue is stored as a positive integer.
		)
	);


	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize,
		'onjob_pro_theme_options[colorscheme_hue]',
			array(
				'section'  => 'colors',
			)
		)
	);

	// Add panel for common theme options
	$wp_customize->add_panel( 'onjob_pro_theme_options_panel',
		array(
			'title'      => esc_html__( 'Theme Options','onjob-pro' ),
			'description'=> esc_html__( ' Onjob Pro Theme Options.', 'onjob-pro' ),
			'priority'   => 150,
		)
	);

	// homepage sortable
	require get_template_directory() . '/inc/customizer/theme-options/sortable.php';

	// loader
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// breadcrumb
	require get_template_directory() . '/inc/customizer/theme-options/breadcrumb.php';

	// load static homepage option
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';
	
	// excerpt
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	// load layout
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// load menu
	require get_template_directory() . '/inc/customizer/theme-options/menu.php';

	// load archive option
	require get_template_directory() . '/inc/customizer/theme-options/archive.php';
	
	// load single post option
	require get_template_directory() . '/inc/customizer/theme-options/single-posts.php';

	// load pagination option
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// load footer option
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// load reset option
	require get_template_directory() . '/inc/customizer/theme-options/reset.php';

	// Add panel for front page theme options.
	$wp_customize->add_panel( 'onjob_pro_front_page_panel',
		array(
			'title'      => esc_html__( 'Front Page','onjob-pro' ),
			'description'=> esc_html__( 'Front Page Theme Options.', 'onjob-pro' ),
			'priority'   => 140,
		)
	);

	// Homepage Layout option
	require get_template_directory() . '/inc/customizer/sections/homepage-layout.php';

	// load slider option
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// load search option
	require get_template_directory() . '/inc/customizer/sections/search.php';
		
	// load course option
	require get_template_directory() . '/inc/customizer/sections/course.php';
		
	// load featured-post option
	require get_template_directory() . '/inc/customizer/sections/featured-post.php';
	
	// load featured option
	require get_template_directory() . '/inc/customizer/sections/featured-job.php';
	
	// load recent-job option
	require get_template_directory() . '/inc/customizer/sections/recent-job.php';
	
	// load magazine-popular-post option
	require get_template_directory() . '/inc/customizer/sections/magazine-popular-post.php';
	
	// load magazine-recent-post option
	require get_template_directory() . '/inc/customizer/sections/magazine-recent-post.php';

	// load magazine-sport-news option
	require get_template_directory() . '/inc/customizer/sections/magazine-sport-news.php';
	
	// load service option
	require get_template_directory() . '/inc/customizer/sections/service.php';
	
	// load about option
	require get_template_directory() . '/inc/customizer/sections/about.php';
	
	// load promotion option
	require get_template_directory() . '/inc/customizer/sections/promotion.php';
	
	// load team option
	require get_template_directory() . '/inc/customizer/sections/team.php';

	// load video option
	require get_template_directory() . '/inc/customizer/sections/video.php';
	
	// load counter option
	require get_template_directory() . '/inc/customizer/sections/counter.php';
	
	// // load gallery option
	require get_template_directory() . '/inc/customizer/sections/gallery.php';

	// load recent-product option
	require get_template_directory() . '/inc/customizer/sections/recent-product.php';
	
	// load subscription option
	require get_template_directory() . '/inc/customizer/sections/subscription.php';
	
	// load testimonial option
	require get_template_directory() . '/inc/customizer/sections/testimonial.php';

	// load company-profile option
	require get_template_directory() . '/inc/customizer/sections/company-profile.php';

	// load latest-post option
	require get_template_directory() . '/inc/customizer/sections/latest-post.php';
	
	// load most-viewed option
	require get_template_directory() . '/inc/customizer/sections/most-viewed.php';
	
	// load sponsor option
	require get_template_directory() . '/inc/customizer/sections/sponsor.php';
		
	// load blog option
	require get_template_directory() . '/inc/customizer/sections/blog.php';

}
add_action( 'customize_register', 'onjob_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function onjob_pro_customize_preview_js() {
	wp_enqueue_script( 'onjob-pro-customizer', get_template_directory_uri() . '/assets/js/customizer' . onjob_pro_min() . '.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'onjob_pro_customize_preview_js' );

/**
 * Load dynamic logic for the customizer controls area.
 */
function onjob_pro_customize_control_js() {
	// Choose from select jquery.
	wp_enqueue_style( 'chosen-css', get_template_directory_uri() . '/assets/css/chosen' . onjob_pro_min() . '.css' );

	wp_enqueue_script( 'jquery-chosen', get_template_directory_uri() . '/assets/js/chosen.jquery' . onjob_pro_min() . '.js', array( 'jquery' ), '1.4.2', true );

	// simple icon picker
	wp_enqueue_style( 'simple-iconpicker-css', get_template_directory_uri() . '/assets/css/simple-iconpicker' . onjob_pro_min() . '.css' );

	wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome' . onjob_pro_min() . '.css' );

	wp_enqueue_script( 'jquery-simple-iconpicker', get_template_directory_uri() . '/assets/js/simple-iconpicker' . onjob_pro_min() . '.js', array( 'jquery' ), '', true );

	wp_enqueue_style( 'onjob-pro-customize-controls-css', get_template_directory_uri() . '/assets/css/customize-controls' . onjob_pro_min() . '.css' );

	wp_enqueue_script( 'onjob-pro-customize-controls', get_template_directory_uri() . '/assets/js/customize-controls' . onjob_pro_min() . '.js', array(), '1.0', true );

	$onjob_pro_reset_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'onjob-pro' )
	);
	// Send list of color variables as object to custom customizer js
	wp_localize_script( 'onjob-pro-customize-controls', 'onjob_pro_reset_data', $onjob_pro_reset_data );
}
add_action( 'customize_controls_enqueue_scripts', 'onjob_pro_customize_control_js' );

if ( !function_exists( 'onjob_pro_reset_options' ) ) :
	/**
	 * Reset all options
	 *
	 * @since  Onjob Pro 1.0.0
	 *
	 * @param bool $checked Whether the reset is checked.
	 * @return bool Whether the reset is checked.
	 */
	function onjob_pro_reset_options() {
		$options = onjob_pro_get_theme_options();
		if ( true === $options['reset_options'] ) {
			// Reset custom theme options.
			set_theme_mod( 'onjob_pro_theme_options', array() );
			// Reset custom header and backgrounds.
			remove_theme_mod( 'header_image' );
			remove_theme_mod( 'header_image_data' );
			remove_theme_mod( 'background_image' );
			remove_theme_mod( 'background_color' );
			remove_theme_mod( 'header_textcolor' );
	    }
	  	else {
		    return false;
	  	}
	}
endif;
add_action( 'customize_save_after', 'onjob_pro_reset_options' );
