<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 * @return array An array of default values
 */

function onjob_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$onjob_pro_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',
		'colorscheme_hue'				    => '#fe463a',
		'colorscheme'					    => 'default',
		'theme_version'						=> 'lite-version',
		'home_layout'						=> 'pro-design',

		// typography Options
		'theme_typography' 				    => 'default',
		'body_theme_typography' 		    => 'default',
		
		// loader
		'loader_enable'         		    => (bool) false,
		'loader_icon'         			    => 'default',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,
		'search_icon_in_primary_menu_enable'=> (bool) true,
		'primary_menu_button'        	    => esc_html__( 'For Employee', 'onjob-pro' ),
		'primary_menu_label1'        	    => esc_html__( 'Login', 'onjob-pro' ),
		'primary_menu_label2'        	    => esc_html__( 'SignUp', 'onjob-pro' ),

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'onjob-pro' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s WordPress Theme %2$s.', '1: Year, 2: Site Title with home URL', 'onjob-pro' ), '[the-year]', '[site-link]' ),
		'theme_credit'           		    => sprintf( esc_html__( 'All Rights Reserved  %1$s', 'onjob-pro' ),  '&nbsp;' . esc_html__( 'by', 'onjob-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>'),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,search,course,featured_post,main_post,magazine_sport_news,featured_job,recent_job,service,about,promotion,team,video,recent_products,counter,gallery,testimonial,subscription,company_profile,latest_post,most_viewed,blog,sponsor',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'onjob-pro' ),
		'blog_column'						=> 'col-2',
		'hide_date'							=> (bool) false,
		'hide_category'						=> (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,
		
		/* Front Page */
		'main_post_section_enable'			    => (bool) true,

		// Slider
		'slider_section_enable'				=> (bool) true,
		'slider_content_type'				=> 'post',
		'slider_count'						=> 3,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_excerpt_length'				=> 25,
		'slider_btn_txt'                    => esc_html__('Learn More','onjob-pro'),
		'slider_btn_alt_txt'                => esc_html__('Get Started','onjob-pro'),

		//search 
		'search_section_enable'			    => (bool) true,
		'search_content_type'			    =>'post',
		'search_custom_title'				=> esc_html__('Find the best Job, vacancy, career online','onjob-pro'),
		'search_custom_content'				=> esc_html__('Many people become social media experts, while others have an interest in web designing and app development.','onjob-pro'),
		'search_btn_txt'                    => esc_html__('Search Now','onjob-pro'),

		// Slider
		'featured_post_section_enable'			=> (bool) true,
		'featured_post_content_type'			=> 'page',
		'featured_post_count'					=> 3,
		
		//popular_post 
		'popular_post_section_enable'		   => (bool) true,
		'popular_post_content_type'			   => 'post',
		'popular_post_count'				   => 3,
		'popular_post_column'				   => 'col-2',
		'popular_post_read_more_btn_label'     => esc_html__('Read Full Post','onjob-pro'),
		
		//most_viewed 
		'most_viewed_section_enable'		   => (bool) true,
		'most_viewed_content_type'			   => 'post',
		'most_viewed_count'				 	   => 4,
		'most_viewed_column'				   => 'col-4',
		'most_viewed_title'					   => esc_html__( 'YOU MAY HAVE MISSED', 'onjob-pro' ),
		
		//service
		'service_section_enable'		    => (bool) true,
		'service_section_sub_title'			=> esc_html__( 'Services', 'onjob-pro' ),
		'service_content_type'			    =>'post',
		'service_posts_count'			    => 3,
		'service_excerpt_length'			=> 20,
		'service_section_title'			    => esc_html__( 'What We Do', 'onjob-pro' ),
		'service_read_more_btn_label'		=> esc_html__( 'Read More', 'onjob-pro' ),

		//testimonial
        'testimonial_section_enable'        => (bool) true,
        'testimonial_autoplay_enable'       => (bool) true,
		'testimonial_section_sub_title'     => esc_html__('Our Testimonial','onjob-pro'),
		'testimonial_section_title'	        => esc_html__('What They Say About Our Company?','onjob-pro'),
		'testimonial_content_type'          => 'post',
		'testimonial_posts_count'           => 4,
		
		// course
		'course_section_enable'				=> (bool) true,
		'course_title'					    => esc_html__( 'Popular Courses to Learn', 'onjob-pro' ),
		'course_sub_title'          		=> esc_html__('Browse Categories','onjob-pro'),
		'course_content_type'				=> 'post',
		'course_count'						=> 3,
		'course_excerpt_length'				=> 25,
		'course_btn_txt'                    => esc_html__('View Course Detail','onjob-pro'),

		// blog
		'blog_section_enable'			    => (bool) true,
		'blog_title'					    => esc_html__( 'Find what’s happening around our circle', 'onjob-pro' ),
		'blog_content_type'				    => 'recent',
		'blog_count'					    => 3,
		'blog_read_more_btn_label'	 	    => esc_html__( 'Show All Article', 'onjob-pro' ),

		// featured_job
		'featured_job_section_enable'			    => (bool) true,
		'featured_job_title'					    => esc_html__( 'Search by category', 'onjob-pro' ),
		'featured_job_sub_title'				    => esc_html__( 'Choose career', 'onjob-pro' ),
		'featured_job_content_type'				    => 'post',
		'featured_job_count'					    => 5,
		
		// recent_job
		'recent_job_section_enable'				=> (bool) true,
		'recent_job_title'					    => esc_html__( 'Top jobs this week', 'onjob-pro' ),
		'recent_job_sub_title'          		=> esc_html__('12000+ jobs available','onjob-pro'),
		'recent_job_content_type'				=> 'post',
		'recent_job_count'						=> 3,
		'recent_job_btn_txt'                    => esc_html__('Show all jobs','onjob-pro'),

		// company_profile
		'company_profile_section_enable'			=> (bool) true,
		'company_profile_title'					    => esc_html__( 'Find your second home', 'onjob-pro' ),
		'company_profile_sub_title'          		=> esc_html__('3800+ startups','onjob-pro'),
		'company_profile_content_type'				=> 'post',
		'company_profile_count'						=> 3,
		'company_profile_btn_txt'                   => esc_html__('View Course Detail','onjob-pro'),

		//about 
		'about_section_enable'			    => (bool) true,
		'about_content_type'			    =>'post',
		'about_custom_title'				=> esc_html__('Welcome to World Best Business Company','onjob-pro'),
		'about_section_title'				=> esc_html__('About Us','onjob-pro'),
		'about_custom_content'				=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry\'s standardLorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.','onjob-pro'),
		'about_btn_txt'                     => esc_html__('Learn More','onjob-pro'),

		// latest_post
		'latest_post_section_enable'		    => (bool) true,
		'latest_post_title'					    => esc_html__( 'Latest News', 'onjob-pro' ),
		'latest_post_content_type'			    => 'recent',
		'latest_post_count'					    => 3,
		'latest_post_read_more_btn_label'	    => esc_html__( 'Read More', 'onjob-pro' ),

		// Popular Post
		'gallery_section_enable'		=> (bool) true,
		'gallery_sub_title'         	=> esc_html__('Portfolio','onjob-pro'),
		'gallery_content_type'			=> 'recent',
		'gallery_count'					=> 6,
		'gallery_title'					=> esc_html__( 'Completed Projects', 'onjob-pro' ),
		'gallery_btn_title'				=> esc_html__( 'Show All', 'onjob-pro' ),
		
		// team
		'team_section_enable'			=> true,
		'team_content_type'				=> 'category',
		'team_count'					=> 3,
		'team_column'					=> 'col-3',
		'team_title'					=> esc_html__( 'Meet Our Team', 'onjob-pro' ),
		'team_sub_title'				=> esc_html__( 'Our Team', 'onjob-pro' ),
		'team_btn_title'				=> esc_html__( 'View All Team', 'onjob-pro' ),
		
		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,

		//promotion
		'promotion_section_enable' 		=> true,
		'promotion_content_type'		=> 'post',
		'promotion_read_more'			=>	esc_html__('Contact Us', 'onjob-pro'),
		'promotion_excerpt_length'		=>	31,
		
		// Sponsor
		'sponsor_section_enable'			=> (bool) true,
		'sponsor_content_type'				=> 'custom',
		'sponsor_count'						=> 5,
				
		//subscription
		'subscription_section_enable' 		=> true,
		'subscription_section_policy'	=>	esc_html__('Subscribe', 'onjob-pro'),
		'subscription_section_title'		=>	esc_html__('Don’t miss our updates. Sign in to subscribe.', 'onjob-pro'),
		'subscription_section_description'	=>	esc_html__('Many people become social media experts, while others have an interest in web designing and app development.', 'onjob-pro'),
		'subscription_section_btn_txt'		=>	esc_html__('Subscribe Now', 'onjob-pro'),
				
		//video
		'video_section_enable' 		=> true,
		'video_section_sub_title'	=>	esc_html__('Video', 'onjob-pro'),
		'video_section_title'		=>	esc_html__('The Most Popular WordPress', 'onjob-pro'),
		
		// recent products
		'recent_products_section_enable'		=> (bool) true,
		'recent_products_count'					=> 4,
		'recent_products_title'					=> esc_html__('Our Latest Products','onjob-pro'),
		'recent_products_sub_title'				=> esc_html__('Discover','onjob-pro'),
		'recent_products_add_to_cart_btn_label'	=> esc_html__('Add To Cart','onjob-pro'),
		'recent_products_content_type'			=> 'product',
						
		//magazine_popular_post 
		'magazine_popular_post_section_enable'		   => (bool) true,
		'magazine_popular_post_content_type'		   => 'post',
		'magazine_popular_post_section_title'		   => esc_html__( 'Popular Posts', 'onjob-pro' ),
		'magazine_popular_post_count'				   => 5,
				
		//magazine_recent_post 
		'magazine_recent_post_section_enable'		  => (bool) true,
		'magazine_recent_post_content_type'		 	  => 'post',
		'magazine_recent_post_section_title'		  => esc_html__( 'Recents Posts', 'onjob-pro' ),
		'magazine_recent_post_count'				  => 4,
				
		//magazine_sport_news 
		'magazine_sport_news_section_enable'	   => (bool) true,
		'magazine_sport_news_content_type'		   => 'post',
		'magazine_sport_news_section_title'		   => esc_html__( 'Sports News', 'onjob-pro' ),
		'magazine_sport_news_count'				   => 4,
		
		
		'enable_footer_search'			   => (bool) true,
		'footer_search_title'		  	  => esc_html__( 'You are now seeing jobs from Nepal.', 'onjob-pro' ),
		'footer_search_placeholder'		  => esc_html__( 'Job title or keyword', 'onjob-pro' ),
		'footer_search_button_label'   	  => esc_html__( 'Search Job', 'onjob-pro' ),
	);

	$output = apply_filters( 'onjob_pro_default_theme_options', $onjob_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}