<?php
/**
 * About Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add About section
$wp_customize->add_section( 'onjob_pro_about_section',
	array(
		'title'             => esc_html__( 'About us','onjob-pro' ),
		'description'       => esc_html__( 'About us  Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'   => 'onjob_pro_is_second_design_enable',
	)
);

// About content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[about_section_enable]',
	array(
		'default'			=> 	$options['about_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[about_section_enable]',
		array(
			'label'             => esc_html__( 'About Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_about_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[about_section_enable]',
		array(
			'selector'            => '#about-section .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[about_section_enable]',
		)
	);
}

// about section title control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[about_section_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> 	$options['about_section_title'],
		'transport'			=>'postMessage'
	)
);

$wp_customize->add_control('onjob_pro_theme_options[about_section_title]',
	array(
		'label'             => esc_html__( 'Section Sub Title', 'onjob-pro' ),
		'section'           => 'onjob_pro_about_section',
		'type'              =>'text',
		'active_callback'	=> 'onjob_pro_is_about_section_enable',
	)
);

$wp_customize->selective_refresh->add_partial('onjob_pro_theme_options[about_section_title]',
    array(
        'selector'            => '#about-section p.section-subtitle',
        'render_callback'     => 'onjob_pro_about_section_partial_title',
    )
);

// About content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options_about_content_type',
	array(
		'default'          	=> $options['about_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options_about_content_type',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_about_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_about_section_enable',
		'choices'			=> array( 
				'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
				'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
				'category' 	=> esc_html__( 'Category', 'onjob-pro' ),
				'custom' 	=> esc_html__( 'Custom', 'onjob-pro' ),
		),
	)
);

	// about pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[about_content_page]',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[about_content_page]',
			array(
				'label'             => esc_html__( 'Select Page', 'onjob-pro' ),
				'section'           => 'onjob_pro_about_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_about_section_content_page_enable',
			)
		)
	);

	// about posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[about_content_post]',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[about_content_post]',
			array(
				'label'             => esc_html__( 'Select Post', 'onjob-pro' ),
				'section'           => 'onjob_pro_about_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_about_section_content_post_enable',
			)
		)
	);


// about posts drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[about_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[about_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'onjob-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'onjob_pro_about_section',
			'active_callback'	=> 'onjob_pro_is_about_section_content_category_enable',
		)
	)
); 

// About title setting
$wp_customize->add_setting('onjob_pro_theme_options[about_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['about_custom_title']
    )
);

$wp_customize->add_control('onjob_pro_theme_options[about_custom_title]',
    array(
        'section'			=> 'onjob_pro_about_section',
        'label'				=> esc_html__( 'Title:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_if_about_section_content_custom_enable'
    )
);

// About content setting
$wp_customize->add_setting('onjob_pro_theme_options[about_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'default'           => $options['about_custom_content']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[about_custom_content]',
    array(
        'section'			=> 'onjob_pro_about_section',
        'label'				=> esc_html__( 'Content:', 'onjob-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'onjob_pro_if_about_section_content_custom_enable'
    )
);

// About Backround image setting
$wp_customize->add_setting('onjob_pro_theme_options[about_custom_image]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'onjob_pro_theme_options[about_custom_image]',
        array(
            'section'			=> 'onjob_pro_about_section',
            'label'				=> esc_html__( 'About Image:', 'onjob-pro' ),
            'active_callback' 	=> 'onjob_pro_if_about_section_content_custom_enable',
        )
    )
);

//slider_btn_txt
$wp_customize->add_setting('onjob_pro_theme_options[about_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['about_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[about_btn_txt]',
    array(
        'section'			=> 'onjob_pro_about_section',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_is_about_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[about_btn_txt]',
		array(
			'selector'            => '#about-section div.read-more a',
			'settings'            => 'onjob_pro_theme_options[about_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_about_btn_txt_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[about_us_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[about_us_btn_url]',
	array(
		'label'           	=>  esc_html__( 'About Us Button Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_about_section',
		'active_callback' 	=> 'onjob_pro_if_about_section_content_custom_enable',
		'type'				=> 'url',
	)
);
