<?php
/**
 * Company Profile Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Company Profile section
$wp_customize->add_section( 'onjob_pro_company_profile_section',
	array(
		'title'             => esc_html__( 'Company Profile','onjob-pro' ),
		'description'       => esc_html__( 'Company Profile Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'	=> 'onjob_pro_is_pro_design_enable',
	)
);

// Company Profile content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_section_enable]',
	array(
		'default'			=> 	$options['company_profile_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[company_profile_section_enable]',
		array(
			'label'             => esc_html__( 'Company Profile Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_company_profile_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[company_profile_section_enable]',
		array(
			'selector'            => '#blog-featured-posts .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[company_profile_section_enable]',
		)
	);
}

// Company Profile section sub title control and setting
$wp_customize->add_setting('onjob_pro_theme_options[company_profile_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['company_profile_sub_title'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[company_profile_sub_title]',
    array(
        'label'             => esc_html__('Section Sub Title', 'onjob-pro'),
        'section'           => 'onjob_pro_company_profile_section',
        'type'              => 'text',
        'active_callback'   => 'onjob_pro_is_company_profile_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[company_profile_sub_title]',
        array(
            'selector'            => '#company-profiles .section-header p.section-subtitle',
            'settings'            => 'onjob_pro_theme_options[company_profile_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_company_profile_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[company_profile_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_company_profile_section',
        'active_callback'   => 'onjob_pro_is_company_profile_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[company_profile_title]',
        array(
            'selector'            => '#company-profiles .section-header h2.section-title',
            'settings'            => 'onjob_pro_theme_options[company_profile_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_company_profile_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_count]',
	array(
		'default'          	=> $options['company_profile_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_company_profile_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[company_profile_count]',
	array(
		'label'             => esc_html__( 'Number of Company Profile', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_company_profile_section',
		'active_callback'   => 'onjob_pro_is_company_profile_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	)
);

// Company Profile content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_content_type]',
	array(
		'default'          	=> $options['company_profile_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[company_profile_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_company_profile_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_company_profile_section_enable',
        'choices'           => onjob_pro_company_profile_content_type()
		
	)
);

for ( $i = 1; $i <= $options['company_profile_count']; $i++ ) :

	// company_profile hr setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_hr_'. $i .']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_html'
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Customize_Horizontal_Line( $wp_customize,
		'onjob_pro_theme_options[company_profile_hr_'. $i .']',
			array(
				'section'         => 'onjob_pro_company_profile_section',
				'active_callback' => 'onjob_pro_is_company_profile_section_content_seperator_enable',
				'type'			  => 'hr'
			)
		)
	);

	// company_profile pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_content_page_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[company_profile_content_page_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_company_profile_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_company_profile_section_content_page_enable',
			)
		)
	);

	// company_profile posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_content_post_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[company_profile_content_post_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_company_profile_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_company_profile_section_content_post_enable',
			)
		)
	);

	// company_profile posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_content_job_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[company_profile_content_job_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Job %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_company_profile_section',
				'choices'			=> onjob_pro_job_listing_choices(),
				'active_callback'	=> 'onjob_pro_is_company_profile_section_content_job_enable',
			)
		)
	);

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[company_profile_content_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[company_profile_content_category]',
		array(
			'label'             => esc_html__( 'Select Category', 'onjob-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'section'           => 'onjob_pro_company_profile_section',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'onjob_pro_is_company_profile_section_content_category_enable'
		)
	)
);


if(class_exists('WP_Job_Manager')){
    // Add dropdown categories setting and control.
    $wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_content_job_listing_category]',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_job_category_list',
        )
    );
    
    $wp_customize->add_control( new Onjob_Pro_Dropdown_Multiple_Chooser( $wp_customize,
        'onjob_pro_theme_options[company_profile_content_job_listing_category]', 
            array(
                'label'             => esc_html__( 'Select Jobs Categories', 'onjob-pro' ),
                'section'           => 'onjob_pro_company_profile_section',
                'type'              => 'dropdown_multiple_chooser',
                'choices'           =>  onjob_pro_job_category_choices(),
                'active_callback'   => 'onjob_pro_is_company_profile_section_content_job_listing_category_enable'
            )
        )
    );
}

//company_profile_btn_txt
$wp_customize->add_setting('onjob_pro_theme_options[company_profile_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['company_profile_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[company_profile_btn_txt]',
    array(
        'section'			=> 'onjob_pro_company_profile_section',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_is_company_profile_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[company_profile_btn_txt]',
		array(
			'selector'            => '#company-profiles div.show-all a',
			'settings'            => 'onjob_pro_theme_options[company_profile_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_company_profile_btn_txt_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[company_profile_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[company_profile_btn_url]',
	array(
		'label'           	=>  esc_html__( 'Button Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_company_profile_section',
		'active_callback' 	=> 'onjob_pro_is_company_profile_section_enable',
		'type'				=> 'url',
	)
);
