<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'onjob_pro_counter_section',
	array(
		'title'             => esc_html__( 'Counters','onjob-pro' ),
		'description'       => esc_html__( 'Counters Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
        'active_callback' 	=> 'onjob_pro_is_second_design_enable',

	)
);

// Counter content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[counter_section_enable]',
	array(
		'default'			=> 	$options['counter_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[counter_section_enable]',
		array(
			'label'             => esc_html__( 'Counter Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_counter_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[counter_section_enable]',
		array(
			'selector'            => '#counter .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[counter_section_enable]',
		)
	);
}


$wp_customize->add_setting( 'onjob_pro_theme_options[counter_image]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'onjob_pro_theme_options[counter_image]',
		array(
			'label'       		=> esc_html__( 'Background Image', 'onjob-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'onjob-pro' ), 1350, 385 ),
			'section'     		=> 'onjob_pro_counter_section',
			'active_callback'	=> 'onjob_pro_is_counter_section_enable',
		)
	)
);

// counter number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[counter_count]',
	array(
		'default'          	=> $options['counter_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_counter_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[counter_count]',
	array(
		'label'             => esc_html__( 'Number of Counters', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_counter_section',
		'active_callback'   => 'onjob_pro_is_counter_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 5,
			'style' => 'width: 100px;'
		),
	)
);

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter title setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[counter_title_' . $i . ']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[counter_title_' . $i . ']',
		array(
			'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'onjob-pro' ), $i ),
			'section'        	=> 'onjob_pro_counter_section',
			'active_callback' 	=> 'onjob_pro_is_counter_section_enable',
			'type'				=> 'text',
		)
	);

	// counter note control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[counter_icon_' . $i . ']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new Onjob_Pro_Icon_Picker( $wp_customize,
		'onjob_pro_theme_options[counter_icon_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Icon %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_counter_section',
				'active_callback'	=> 'onjob_pro_is_counter_section_enable',
			)
		)
	);

	// counter title setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[counter_number_' . $i . ']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[counter_number_' . $i . ']',
		array(
			'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'onjob-pro' ), $i ),
			'section'        	=> 'onjob_pro_counter_section',
			'active_callback' 	=> 'onjob_pro_is_counter_section_enable',
			'type'				=> 'text',
		)
	);

	// counter hr setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[counter_hr_'. $i .']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_html'
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Customize_Horizontal_Line( $wp_customize,
		'onjob_pro_theme_options[counter_hr_'. $i .']',
			array(
				'section'         => 'onjob_pro_counter_section',
				'active_callback' => 'onjob_pro_is_counter_section_enable',
				'type'			  => 'hr'
			)
		)
	);
	
endfor;