<?php
/**
 * Course Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Course section
$wp_customize->add_section( 'onjob_pro_course_section',
	array(
		'title'             => esc_html__( 'Course','onjob-pro' ),
		'description'       => esc_html__( 'Course Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'   => 'onjob_pro_is_third_design_enable',
	)
);

// Course content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[course_section_enable]', 
	array(
		'default'			=> 	$options['course_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[course_section_enable]',
		array(
			'label'             => esc_html__( 'Course Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_course_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Course section sub title control and setting
$wp_customize->add_setting('onjob_pro_theme_options[course_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['course_sub_title'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[course_sub_title]',
    array(
        'label'             => esc_html__('Section Sub Title', 'onjob-pro'),
        'section'           => 'onjob_pro_course_section',
        'type'              => 'text',
        'active_callback'   => 'onjob_pro_is_course_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[course_sub_title]',
        array(
            'selector'            => '#course-section .section-header p.section-subtitle',
            'settings'            => 'onjob_pro_theme_options[course_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_course_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[course_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[course_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_course_section',
        'active_callback'   => 'onjob_pro_is_course_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[course_title]',
        array(
            'selector'            => '#course-section .section-header h2.section-title',
            'settings'            => 'onjob_pro_theme_options[course_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_course_title_partial',
        )
    );
}

// Course number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[course_count]',
	array(
		'default'          	=> $options['course_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_course_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[course_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_course_section',
		'active_callback'   => 'onjob_pro_is_course_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	)
);

// Course content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[course_content_type]',
	array(
		'default'          	=> $options['course_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[course_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_course_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_course_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
			'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
			'category' 	=> esc_html__( 'Category', 'onjob-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['course_count']; $i++ ) :

	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[course_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[course_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_course_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_course_section_content_page_enable',
			)
		)
	);

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[course_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[course_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_course_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_course_section_content_post_enable',
			)
		)
	);

	// Onjob_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('onjob_pro_theme_options[course_separator'. $i .']',
		array(
			'sanitize_callback'      => 'onjob_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Onjob_Pro_Customize_Horizontal_Line($wp_customize,
		'onjob_pro_theme_options[course_separator'. $i .']',
			array(
				'active_callback'       => 'onjob_pro_is_course_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'onjob_pro_course_section',
			)
		)
	);

endfor;

// slider posts drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[course_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[course_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'onjob-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'onjob_pro_course_section',
			'active_callback'	=> 'onjob_pro_is_course_section_content_category_enable',
		)
	)
); 

// Course Excerpt length setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[course_excerpt_length]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'default'			=> $options['course_excerpt_length'],
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[course_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'onjob-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Course section', 'onjob-pro' ),
		'section'     		=> 'onjob_pro_course_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'onjob_pro_is_course_section_enable',
	)
);


//course_btn_txt
$wp_customize->add_setting('onjob_pro_theme_options[course_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['course_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[course_btn_txt]',
    array(
        'section'			=> 'onjob_pro_course_section',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_is_course_section_enable'
    )
);