<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'onjob_pro_featured_job_section',
    array(
        'title'             => esc_html__( 'Featured Jobs','onjob-pro' ),
        'description'       => esc_html__( 'Featured Jobs Section options.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
        'active_callback'   => 'onjob_pro_is_pro_design_enable',
    )
);

// Featured Jobs content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_section_enable]',
    array(
        'default'           =>  $options['featured_job_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[featured_job_section_enable]',
        array(
            'label'             => esc_html__( 'Featured Jobs Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_featured_job_section',
            'on_off_label'      => onjob_pro_switch_options(),
        ) 
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[featured_job_section_enable]',
        array(
            'selector'            => '#featured-jobs .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[featured_job_section_enable]',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['featured_job_sub_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[featured_job_sub_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_featured_job_section',
        'active_callback'   => 'onjob_pro_is_featured_job_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[featured_job_sub_title]',
        array(
            'selector'            => '#featured-jobs div.section-header p',
            'settings'            => 'onjob_pro_theme_options[featured_job_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_featured_job_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['featured_job_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[featured_job_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_featured_job_section',
        'active_callback'   => 'onjob_pro_is_featured_job_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[featured_job_title]',
        array(
            'selector'            => '#featured-jobs div.section-header h2.section-title',
            'settings'            => 'onjob_pro_theme_options[featured_job_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_featured_job_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_count]',
    array(
        'default'           => $options['featured_job_count'],
        'sanitize_callback' => 'onjob_pro_sanitize_number_range',
        'validate_callback' => 'onjob_pro_validate_featured_job_count',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[featured_job_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'onjob-pro' ),
        'description'       => esc_html__( 'Note: Min 2 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
        'section'           => 'onjob_pro_featured_job_section',
        'active_callback'   => 'onjob_pro_is_featured_job_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 2,
            'max'   => 12,
            'style' => 'width: 100px;'
        ),
    ) 
);

// Featured Jobs content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_content_type]',
    array(
        'default'           => $options['featured_job_content_type'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'onjob_pro_theme_options[featured_job_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
        'description'	    => sprintf( esc_html__( '%1$sWP Job Manager %2$s should be installed and active to enable job and company content type', 'onjob-pro' ), '<a target="_blank" href="'.admin_url('themes.php?page=tgmpa-install-plugins&plugin_status=install').'">', '</a>' ),
        'section'           => 'onjob_pro_featured_job_section',
        'type'              => 'select',
        'active_callback'   => 'onjob_pro_is_featured_job_section_enable',
        'choices'           => onjob_pro_featured_job_content_type()
    ) 
);

// // Add dropdown categories setting and control.
// $wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_content_category]',
//     array(
//         'sanitize_callback' => 'onjob_pro_sanitize_category_list',
//         'validate_callback' => 'onjob_pro_validate_featured_job_category_count',
//     )
// );

// $wp_customize->add_control( new Onjob_Pro_Dropdown_Multiple_Chooser( $wp_customize,
//     'onjob_pro_theme_options[featured_job_content_category]', 
//         array(
//             'label'             => esc_html__( 'Select Categories', 'onjob-pro' ),
//             'section'           => 'onjob_pro_featured_job_section',
//             'type'              => 'dropdown_multiple_chooser',
//             'choices'           =>  onjob_pro_category_choices(),
//             'active_callback'   => 'onjob_pro_is_featured_job_section_content_category_enable'
//         )
//     )
// );

// if(class_exists('WP_Job_Manager')){
//     // Add dropdown categories setting and control.
//     $wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_content_job_listing_category]',
//         array(
//             'sanitize_callback' => 'onjob_pro_sanitize_job_category_list',
//             'validate_callback' => 'onjob_pro_validate_featured_job_category_count',
//         )
//     );
    
//     $wp_customize->add_control( new Onjob_Pro_Dropdown_Multiple_Chooser( $wp_customize,
//         'onjob_pro_theme_options[featured_job_content_job_listing_category]', 
//             array(
//                 'label'             => esc_html__( 'Select Jobs Categories', 'onjob-pro' ),
//                 'section'           => 'onjob_pro_featured_job_section',
//                 'type'              => 'dropdown_multiple_chooser',
//                 'choices'           =>  onjob_pro_job_category_choices(),
//                 'active_callback'   => 'onjob_pro_is_featured_job_section_content_job_listing_category_enable'
//             )
//         )
//     );
// }

for($i = 0; $i < $options['featured_job_count']; $i ++):

    // Onjob_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('onjob_pro_theme_options[featured_job_separator_'. $i .']',
		array(
			'sanitize_callback'      => 'onjob_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Onjob_Pro_Customize_Horizontal_Line($wp_customize,
		'onjob_pro_theme_options[featured_job_separator_'. $i .']',
			array(
				'active_callback'       => 'onjob_pro_is_featured_job_section_enable',
				'type'                  => 'hr',
				'section'               => 'onjob_pro_featured_job_section',
			)
		)
	);
    
    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[featured_job_content_page_' . $i . ']', 
            array(
                'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), ($i+1) ),
                'section'           => 'onjob_pro_featured_job_section',
                'choices'           => onjob_pro_page_choices(),
                'active_callback'   => 'onjob_pro_is_featured_job_section_content_page_enable',
            )
        )
    );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_content_post_' . $i . ']', 
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        ) 
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[featured_job_content_post_' . $i . ']', 
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), ($i+1) ),
                'section'           => 'onjob_pro_featured_job_section',
                'choices'           => onjob_pro_post_choices(),
                'active_callback'   => 'onjob_pro_is_featured_job_section_content_post_enable',
            ) 
        )
    );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_content_job_listing_' . $i . ']', 
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        ) 
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[featured_job_content_job_listing_' . $i . ']', 
            array(
                'label'             => sprintf( esc_html__( 'Select Jobs %d', 'onjob-pro' ), ($i+1) ),
                'section'           => 'onjob_pro_featured_job_section',
                'choices'           => onjob_pro_job_listing_choices(),
                'active_callback'   => 'onjob_pro_is_featured_job_section_content_job_listing_enable',
            ) 
        )
    );

    if(class_exists('WP_Job_Manager')){

        // Add dropdown category setting and control.
        $wp_customize->add_setting(  'onjob_pro_theme_options[featured_job_content_job_listing_category_'.$i.']',
            array(
                'sanitize_callback' => 'onjob_pro_sanitize_single_job_listing_category',
            )
        );

        $wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
            'onjob_pro_theme_options[featured_job_content_job_listing_category_'.$i.']',
                array(
                    'label'             => sprintf( esc_html__( 'Select Jobs Category %d', 'onjob-pro' ), ($i+1) ),
                    'section'           => 'onjob_pro_featured_job_section',
                    'type'              => 'dropdown-taxonomies',
                    'taxonomy'          => 'job_listing_category',
                    'active_callback'	=> 'onjob_pro_is_featured_job_section_content_job_listing_category_enable'
                )
            )
        );
    }
            
    // Add dropdown category setting and control.
    $wp_customize->add_setting(  'onjob_pro_theme_options[featured_job_content_category_'.$i.']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_single_category',
        )
    );

    $wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
        'onjob_pro_theme_options[featured_job_content_category_'.$i.']',
            array(
                'label'             => sprintf( esc_html__( 'Select Category %d', 'onjob-pro' ), ($i+1) ),
                'section'           => 'onjob_pro_featured_job_section',
                'type'              => 'dropdown-taxonomies',
                'active_callback'	=> 'onjob_pro_is_featured_job_section_content_category_enable'
            )
        )
    );

    $wp_customize->add_setting( 'onjob_pro_theme_options[featured_job_icon_' . $i . ']', 
        array(
            'sanitize_callback' => 'sanitize_text_field',
            'default'           => 'fa-briefcase',
        )
    );

	$wp_customize->add_control( new Onjob_Pro_Icon_Picker( $wp_customize,
		'onjob_pro_theme_options[featured_job_icon_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Service Icon %d', 'onjob-pro' ), ($i+1) ),
				'section'           => 'onjob_pro_featured_job_section',
				'active_callback'	=> 'onjob_pro_is_featured_job_section_enable',
			)
		)
	);

endfor;