<?php
/**
 * Sport News Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add Sport News section
$wp_customize->add_section( 'onjob_pro_magazine_sport_news_section',
    array(
        'title'             => esc_html__( 'Sport News','onjob-pro' ),
        'description'       => esc_html__( 'Sport News Section options.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'	=> 'onjob_pro_is_fourth_design_enable',

    )
);

// Sport News content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_section_enable]',
    array(
        'default'           =>  $options['magazine_sport_news_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[magazine_sport_news_section_enable]',
        array(
            'label'             => esc_html__( 'Sport News Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_magazine_sport_news_section',
            'on_off_label'      => onjob_pro_switch_options(),
        )
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[magazine_sport_news_section_enable]',
        array(
            'selector'            => '#magazine-sports-news .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[magazine_sport_news_section_enable]',
        )
    );
}

// Service section title control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_section_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['magazine_sport_news_section_title'],
		
	) 
);

$wp_customize->add_control('onjob_pro_theme_options[magazine_sport_news_section_title]', 
	array(
		'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
		'section'           => 'onjob_pro_magazine_sport_news_section',
		'type'              =>'text',
		'active_callback'	=> 'onjob_pro_is_magazine_sport_news_section_enable',
	)
);
	
	// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[magazine_sport_news_section_title]',
		array(
			'selector'            => '#magazine-sports-news div.section-header h2',
			'settings'            => 'onjob_pro_theme_options[magazine_sport_news_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_magazine_sport_news_section_title_partial',
		) 
	);
}

// Event social icons number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_count]',
    array(
        'default'           => $options['magazine_sport_news_count'],
        'sanitize_callback' => 'onjob_pro_sanitize_number_range',
        'validate_callback' => 'onjob_pro_validate_magazine_sport_news_count',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[magazine_sport_news_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'onjob-pro' ),
        'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
        'section'           => 'onjob_pro_magazine_sport_news_section',
        'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 4,
            'max'   => 8,
            'style' => 'width: 100px;'
        ),
    )
);

// Sport News content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_content_type]',
    array(
        'default'           => $options['magazine_sport_news_content_type'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[magazine_sport_news_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
        'section'           => 'onjob_pro_magazine_sport_news_section',
        'type'              => 'select',
        'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_enable',
        'choices'           => array( 
            'page'      => esc_html__( 'Page', 'onjob-pro' ),
            'post'      => esc_html__( 'Post', 'onjob-pro' ),
            'category'  => esc_html__( 'Category', 'onjob-pro' ),
            'recent'    => esc_html__( 'Recent', 'onjob-pro' ),
        ),
    )
);

for ( $i = 1; $i <= $options['magazine_sport_news_count']; $i++ ) :

    // magazine_sport_news pages drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[magazine_sport_news_content_page_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), $i ),
                'section'           => 'onjob_pro_magazine_sport_news_section',
                'choices'           => onjob_pro_page_choices(),
                'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_content_page_enable',
            )
        )
    );

    // magazine_sport_news posts drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[magazine_sport_news_content_post_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), $i ),
                'section'           => 'onjob_pro_magazine_sport_news_section',
                'choices'           => onjob_pro_post_choices(),
                'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_content_post_enable',
            )
        )
    );

    //magazine_sport_news separator
    $wp_customize->add_setting('onjob_pro_theme_options[magazine_sport_news_separator'. $i .']',
        array(
            'sanitize_callback'      => 'onjob_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Onjob_Pro_Customize_Horizontal_Line($wp_customize,
        'onjob_pro_theme_options[magazine_sport_news_separator'. $i .']',
            array(
                'active_callback'       => 'onjob_pro_is_magazine_sport_news_section_separator_enable',
                'type'                  =>'hr',
                'section'               =>'onjob_pro_magazine_sport_news_section',
            )
        )
    );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[magazine_sport_news_content_category]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'onjob_pro_theme_options[magazine_sport_news_content_category]',
        array(
            'label'             => esc_html__( 'Select Category', 'onjob-pro' ),
            'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
            'section'           => 'onjob_pro_magazine_sport_news_section',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_content_category_enable'
        )
    )
);

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[magazine_sport_news_category_exclude]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_category_list',
    )
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Multiple_Chooser( $wp_customize,
    'onjob_pro_theme_options[magazine_sport_news_category_exclude]',
        array(
            'label'             => esc_html__( 'Select Excluding Categories', 'onjob-pro' ),
            'section'           => 'onjob_pro_magazine_sport_news_section',
            'type'              => 'dropdown_multiple_chooser',
            'choices'           =>  onjob_pro_category_choices(),
            'active_callback'   => 'onjob_pro_is_magazine_sport_news_section_content_recent_enable'
        )
    )
);
