<?php
/**
 * Most Viewed Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add Most Viewed section
$wp_customize->add_section( 'onjob_pro_most_viewed_section',
    array(
        'title'             => esc_html__( 'Most Viewed','onjob-pro' ),
        'description'       => esc_html__( 'Most Viewed Section options.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'	=> 'onjob_pro_is_fourth_design_enable',
    )
);

// Most Viewed content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_section_enable]',
    array(
        'default'           =>  $options['most_viewed_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[most_viewed_section_enable]',
        array(
            'label'             => esc_html__( 'Most Viewed Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_most_viewed_section',
            'on_off_label'      => onjob_pro_switch_options(),
        )
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[most_viewed_section_enable]',
        array(
            'selector'            => '#recent-posts-section .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[most_viewed_section_enable]',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['most_viewed_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[most_viewed_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_most_viewed_section',
        'active_callback'   => 'onjob_pro_is_most_viewed_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[most_viewed_title]',
        array(
            'selector'            => '#magazine-most-viewed-posts h2.section-title',
            'settings'            => 'onjob_pro_theme_options[most_viewed_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_most_viewed_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_count]',
    array(
        'default'           => $options['most_viewed_count'],
        'sanitize_callback' => 'onjob_pro_sanitize_number_range',
        'validate_callback' => 'onjob_pro_validate_most_viewed_count',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[most_viewed_count]',
    array(
        'label'             => esc_html__( 'Number of Posts', 'onjob-pro' ),
        'description'       => esc_html__( 'Note: Min 4 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
        'section'           => 'onjob_pro_most_viewed_section',
        'active_callback'   => 'onjob_pro_is_most_viewed_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 4,
            'max'   => 8,
            'style' => 'width: 100px;'
        ),
    )
);

// Most Viewed content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_content_type]',
    array(
        'default'           => $options['most_viewed_content_type'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[most_viewed_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
        'section'           => 'onjob_pro_most_viewed_section',
        'type'              => 'select',
        'active_callback'   => 'onjob_pro_is_most_viewed_section_enable',
        'choices'           => array( 
            'page'      => esc_html__( 'Page', 'onjob-pro' ),
            'post'      => esc_html__( 'Post', 'onjob-pro' ),
            'category'  => esc_html__( 'Category', 'onjob-pro' ),
            'recent'    => esc_html__( 'Recent', 'onjob-pro' ),
        ),
    )
);

for ( $i = 1; $i <= $options['most_viewed_count']; $i++ ) :
    // most_viewed pages drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[most_viewed_content_page_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), $i ),
                'section'           => 'onjob_pro_most_viewed_section',
                'choices'           => onjob_pro_page_choices(),
                'active_callback'   => 'onjob_pro_is_most_viewed_section_content_page_enable',
            )
        )
    );

    // most_viewed posts drop down chooser control and setting
    $wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[most_viewed_content_post_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), $i ),
                'section'           => 'onjob_pro_most_viewed_section',
                'choices'           => onjob_pro_post_choices(),
                'active_callback'   => 'onjob_pro_is_most_viewed_section_content_post_enable',
            )
        )
    );

    //most_viewed separator
    $wp_customize->add_setting('onjob_pro_theme_options[most_viewed_separator'. $i .']',
        array(
            'sanitize_callback'      => 'onjob_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new Onjob_Pro_Customize_Horizontal_Line($wp_customize,
        'onjob_pro_theme_options[most_viewed_separator'. $i .']',
            array(
                'active_callback'       => 'onjob_pro_is_most_viewed_section_separator_enable',
                'type'                  =>'hr',
                'section'               =>'onjob_pro_most_viewed_section',
            )
        )
    );

endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[most_viewed_content_category]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_single_category',
    )
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'onjob_pro_theme_options[most_viewed_content_category]',
        array(
            'label'             => esc_html__( 'Select Category', 'onjob-pro' ),
            'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
            'section'           => 'onjob_pro_most_viewed_section',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'onjob_pro_is_most_viewed_section_content_category_enable'
        )
    )
);

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_category_exclude]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_category_list',
    )
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Multiple_Chooser( $wp_customize,
    'onjob_pro_theme_options[most_viewed_category_exclude]',
        array(
            'label'             => esc_html__( 'Select Excluding Categories', 'onjob-pro' ),
            'section'           => 'onjob_pro_most_viewed_section',
            'type'              => 'dropdown_multiple_chooser',
            'choices'           =>  onjob_pro_category_choices(),
            'active_callback'   => 'onjob_pro_is_most_viewed_section_content_recent_enable'
        )
    )
);

// most_viewed content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[most_viewed_column]',
    array(
        'default'          	=> $options['most_viewed_column'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[most_viewed_column]',
    array(
        'label'             => esc_html__( 'Column Layout', 'onjob-pro' ),
        'section'           => 'onjob_pro_most_viewed_section',
        'type'				=> 'select',
        'active_callback' 	=> 'onjob_pro_is_most_viewed_section_enable',
        'choices'			=> array( 
            'col-1'		=> esc_html__( 'One Column', 'onjob-pro' ),
            'col-2'		=> esc_html__( 'Two Column', 'onjob-pro' ),
            'col-3'		=> esc_html__( 'Three Column', 'onjob-pro' ),
            'col-4'		=> esc_html__( 'Four Column', 'onjob-pro' ),
        ),
    )
);