<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Promotion section
$wp_customize->add_section( 'onjob_pro_promotion_section',
    array(
        'title'             => esc_html__( 'Promotion','onjob-pro' ),
        'description'       => esc_html__( 'Promotion Section options.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
        'active_callback'   => 'onjob_pro_is_second_design_enable',

    )
);

// Promotion content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_section_enable]',
    array(
        'default'			=> 	$options['promotion_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[promotion_section_enable]',
        array(
            'label'             => esc_html__( 'Promotion Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_promotion_section',
            'on_off_label' 		=> onjob_pro_switch_options(),
        )
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[promotion_section_enable]',
        array(
            'selector'            => '#promotion-section .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[promotion_section_enable]',
        )
    );
}

// Promotion content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_content_type]',
    array(
        'default'          	=> $options['promotion_content_type'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    ) 
);

$wp_customize->add_control( 'onjob_pro_theme_options[promotion_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
        'section'           => 'onjob_pro_promotion_section',
        'type'				=> 'select',
        'active_callback' 	=> 'onjob_pro_is_promotion_section_enable',
        'choices'			=> onjob_pro_promotion_content_type(),
    )
);

$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_content_page]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_page',
    )
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
    'onjob_pro_theme_options[promotion_content_page]',
        array(
            'label'             => esc_html__( 'Select Page', 'onjob-pro' ),
            'section'           => 'onjob_pro_promotion_section',
            'choices'			=> onjob_pro_page_choices(),
            'active_callback'	=> 'onjob_pro_is_promotion_section_content_page_enable',
        )
    )
);

// Promotion posts drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_content_post]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_page',
    )
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
    'onjob_pro_theme_options[promotion_content_post]',
        array(
            'label'             => esc_html__( 'Select posts', 'onjob-pro' ),
            'section'           => 'onjob_pro_promotion_section',
            'choices'			=> onjob_pro_post_choices(),
            'active_callback'	=> 'onjob_pro_is_promotion_section_content_post_enable',
        )
    ) 
);

// Promotion read more setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_read_more]',
    array(
        'default'			=> $options['promotion_read_more'],
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         =>'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[promotion_read_more]',
    array(
        'label'           	=> esc_html__( 'Read More Text', 'onjob-pro' ),
        'section'        	=> 'onjob_pro_promotion_section',
        'active_callback' 	=> 'onjob_pro_is_promotion_section_enable',
        'type'				=> 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[promotion_read_more]',
        array(
            'selector'            => '#promotion-section .wrapper .read-more a.btn',
            'settings'            => 'onjob_pro_theme_options[promotion_read_more]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_promotion_read_more_partial',
        )
    );
}


// Promotion Excerpt length setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[promotion_excerpt_length]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'default'			=> $options['promotion_excerpt_length'],
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[promotion_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'onjob-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Promotion section', 'onjob-pro' ),
		'section'     		=> 'onjob_pro_promotion_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'onjob_pro_is_promotion_section_enable',
	)
);
