<?php
/**
 * Recent Jobs Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Recent Jobs section
$wp_customize->add_section( 'onjob_pro_recent_job_section',
	array(
		'title'             => esc_html__( 'Recent Jobs','onjob-pro' ),
        'description'	    => sprintf( esc_html__( '%1$sWP Job Manage%2$s should be installed and active for this section to work.', 'onjob-pro' ), '<a target="_blank" href="'.admin_url('themes.php?page=tgmpa-install-plugins&plugin_status=install').'">', '</a>' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'	=> 'onjob_pro_is_pro_design_enable',
	)
);

// Recent Jobs content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_section_enable]',
	array(
		'default'			=> 	$options['recent_job_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[recent_job_section_enable]',
		array(
			'label'             => esc_html__( 'Recent Jobs Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_recent_job_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_job_section_enable]',
		array(
			'selector'            => '#recent-jobs .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[recent_job_section_enable]',
		)
	);
}

// Recent Jobs section sub title control and setting
$wp_customize->add_setting('onjob_pro_theme_options[recent_job_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['recent_job_sub_title'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[recent_job_sub_title]',
    array(
        'label'             => esc_html__('Section Sub Title', 'onjob-pro'),
        'section'           => 'onjob_pro_recent_job_section',
        'type'              => 'text',
        'active_callback'   => 'onjob_pro_is_recent_job_section_enable',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_job_sub_title]',
        array(
            'selector'            => '#recent-jobs .section-header p.section-subtitle',
            'settings'            => 'onjob_pro_theme_options[recent_job_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_recent_job_sub_title_partial',
        )
    );
}

// blog title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['blog_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_job_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_recent_job_section',
        'active_callback'   => 'onjob_pro_is_recent_job_section_enable',
        'type'              => 'text',
    ) 
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_job_title]',
        array(
            'selector'            => '#recent-jobs .section-header h2.section-title',
            'settings'            => 'onjob_pro_theme_options[recent_job_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_recent_job_title_partial',
        )
    );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_count]',
	array(
		'default'          	=> $options['recent_job_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_recent_job_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_job_count]',
	array(
		'label'             => esc_html__( 'Number of Recent Jobs', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_recent_job_section',
		'active_callback'   => 'onjob_pro_is_recent_job_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	)
);

// Recent Jobs content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_content_type]',
	array(
		'default'          	=> $options['recent_job_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_job_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_recent_job_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_recent_job_section_enable',
		'choices'			=> onjob_pro_featured_job_content_type()
	)
);

for ( $i = 1; $i <= $options['recent_job_count']; $i++ ) :

	// recent_job pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_content_page_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[recent_job_content_page_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_recent_job_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_recent_job_section_content_page_enable',
			)
		)
	);

	// recent_job posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_content_post_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[recent_job_content_post_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_recent_job_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_recent_job_section_content_post_enable',
			)
		)
	);

	// recent_job posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_content_job_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[recent_job_content_job_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Job %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_recent_job_section',
				'choices'			=> onjob_pro_job_listing_choices(),
				'active_callback'	=> 'onjob_pro_is_recent_job_section_content_job_listing_enable',
			)
		)
	);

	// recent_job hr setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_hr_'. $i .']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_html'
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Customize_Horizontal_Line( $wp_customize,
		'onjob_pro_theme_options[recent_job_hr_'. $i .']',
			array(
				'section'         => 'onjob_pro_recent_job_section',
				'active_callback' => 'onjob_pro_is_recent_job_section_content_seperator_enable',
				'type'			  => 'hr'
			)
		)
	);
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[recent_job_content_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[recent_job_content_category]',
		array(
			'label'             => esc_html__( 'Select Category', 'onjob-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'section'           => 'onjob_pro_recent_job_section',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'onjob_pro_is_recent_job_section_content_category_enable'
		)
	)
);

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[recent_job_content_job_listing_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_job_listing_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[recent_job_content_job_listing_category]',
		array(
			'label'             => esc_html__( 'Select Jobs Category', 'onjob-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected job category', 'onjob-pro' ),
			'section'           => 'onjob_pro_recent_job_section',
			'type'              => 'dropdown-taxonomies',
			'taxonomy'          => 'job_listing_category',
			'active_callback'	=> 'onjob_pro_is_recent_job_section_content_job_listing_category_enable'
		)
	)
);

//recent_job_btn_txt
$wp_customize->add_setting('onjob_pro_theme_options[recent_job_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['recent_job_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[recent_job_btn_txt]',
    array(
        'section'			=> 'onjob_pro_recent_job_section',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_is_recent_job_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_job_btn_txt]',
		array(
			'selector'            => '#recent-jobs div.show-all a',
			'settings'            => 'onjob_pro_theme_options[recent_job_btn_txt]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_recent_job_btn_txt_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[recent_job_btn_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_job_btn_url]',
	array(
		'label'           	=>  esc_html__( 'Button Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_recent_job_section',
		'active_callback' 	=> 'onjob_pro_is_recent_job_section_enable',
		'type'				=> 'url',
	)
);
