<?php
/**
 * Recent Products Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_products section
$wp_customize->add_section( 'onjob_pro_recent_products_section',
    array(
        'title'             => esc_html__( 'Recent Product','onjob-pro' ),
        'description'       => esc_html__( 'Note: To activate this section you need to install WooCommerce Plugin.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
        'active_callback'   => 'onjob_pro_is_second_design_enable',

    )
);

// recent_products content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_section_enable]',
    array(
        'default'           =>  $options['recent_products_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[recent_products_section_enable]',
        array(
            'label'             => esc_html__( 'Recent product Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_recent_products_section',
            'on_off_label'      => onjob_pro_switch_options(),
        )
    )
);

// recent_products sub title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['recent_products_sub_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_products_sub_title]',
    array(
        'label'             => esc_html__( 'Section SubTitle', 'onjob-pro' ),
        'section'           => 'onjob_pro_recent_products_section',
        'active_callback'   => 'onjob_pro_is_recent_products_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_products_sub_title]',
        array(
            'selector'            => '#recent-products div.section-header p.section-subtitle',
            'settings'            => 'onjob_pro_theme_options[recent_products_sub_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_recent_products_sub_title_partial',
        )
    );
}

// recent_products title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['recent_products_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_products_title]',
    array(
        'label'             => esc_html__( ' Section Title', 'onjob-pro' ),
        'section'           => 'onjob_pro_recent_products_section',
        'active_callback'   => 'onjob_pro_is_recent_products_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_products_title]',
        array(
            'selector'            => '#recent-products div.section-header h2.section-title',
            'settings'            => 'onjob_pro_theme_options[recent_products_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'onjob_pro_recent_products_title_partial',
        )
    );
}


$wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_count]',
    array(
        'default'           => $options['recent_products_count'],
        'sanitize_callback' => 'onjob_pro_sanitize_number_range',
        'validate_callback' => 'onjob_pro_validate_recent_products_count',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_products_count]',
    array(
        'label'             => esc_html__( 'Number of Product', 'onjob-pro' ),
        'description'       => esc_html__( 'Note: Min 4 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
        'section'           => 'onjob_pro_recent_products_section',
        'active_callback'   => 'onjob_pro_is_recent_products_section_enable',
        'type'              => 'number',
        'input_attrs'       => array(
            'min'   => 4,
            'max'   => 12,
            'style' => 'width: 100px;'
        ),
    )
);

$wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_content_type]',
    array(
        'default'           => $options['recent_products_content_type'],
        'sanitize_callback' => 'onjob_pro_sanitize_select',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[recent_products_content_type]',
    array(
        'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
        'section'           => 'onjob_pro_recent_products_section',
        'type'              => 'select',
        'active_callback'   => 'onjob_pro_is_recent_products_section_enable',
        'choices'           => array(
            'product'           => esc_html__( 'Product', 'onjob-pro' ),
            'product-category'  => esc_html__( 'Product Category', 'onjob-pro' ),
        ),
    )
);

for( $i = 1 ; $i <= $options['recent_products_count'] ; $i++ ){

    //recent_products separator
    $wp_customize->add_setting('onjob_pro_theme_options[recent_products_separator'. $i .']',
        array(
            'sanitize_callback'      => 'onjob_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new  Onjob_Pro_Customize_Horizontal_Line($wp_customize,
        'onjob_pro_theme_options[recent_products_separator'. $i .']',
            array(
                'active_callback'       => 'onjob_pro_is_recent_products_section_separator_enable',
                'type'                  =>'hr',
                'section'               =>'onjob_pro_recent_products_section',
            )
        )
    );
    $wp_customize->add_setting( 'onjob_pro_theme_options[recent_products_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
        'onjob_pro_theme_options[recent_products_content_page_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Product %d', 'onjob-pro' ), $i ),
                'section'           => 'onjob_pro_recent_products_section',
                'choices'           => onjob_pro_product_choices(),
                'active_callback'   => 'onjob_pro_is_recent_products_section_content_product_enable',
            )
        )
    );
}

$wp_customize->add_setting(  'onjob_pro_theme_options[recent_products_category]',
    array(
        'sanitize_callback' => 'absint',
    )
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
    'onjob_pro_theme_options[recent_products_category]',
        array(
            'label'             => esc_html__( 'Select Product Categories', 'onjob-pro' ),
            'description'       => esc_html__( 'Note: Press CTRL and select multiple category. Latest four posts will be shown from each selected category', 'onjob-pro' ),
            'section'           => 'onjob_pro_recent_products_section',
            'taxonomy'          => 'product_cat',
            'type'              => 'dropdown-taxonomies',
            'active_callback'   => 'onjob_pro_is_recent_products_section_content_product_category_enable',
        )
    )
);

// Recent product Add to Cart content setting
$wp_customize->add_setting('onjob_pro_theme_options[recent_products_add_to_cart_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['recent_products_add_to_cart_btn_label']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[recent_products_add_to_cart_btn_label]',
    array(
        'section'			=> 'onjob_pro_recent_products_section',
        'label'				=> esc_html__( 'Add To Cart Button Label', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'onjob_pro_is_recent_products_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[recent_products_add_to_cart_btn_label]',
        array(
            'selector'            => '#recent-products a.add_to_cart_button',
            'settings'            => 'onjob_pro_theme_options[recent_products_add_to_cart_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'onjob_pro_recent_products_add_to_cart_btn_label_partial',
        ) 
    );
}
