<?php
/**
 * Search Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add Search section
$wp_customize->add_section( 'onjob_pro_search_section',
	array(
		'title'             => esc_html__( 'Search Section','onjob-pro' ),
        'description'	    => sprintf( esc_html__( '%1$sWP Job Manage%2$s should be installed and active for this section to work.', 'onjob-pro' ), '<a target="_blank" href="'.admin_url('themes.php?page=tgmpa-install-plugins&plugin_status=install').'">', '</a>' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback' 	=> 'onjob_pro_is_pro_design_enable',
	)
);

// Search content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[search_section_enable]',
	array(
		'default'			=> 	$options['search_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[search_section_enable]',
		array(
			'label'             => esc_html__( 'Search Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_search_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[search_section_enable]',
		array(
			'selector'            => '#search-section .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[search_section_enable]',
		)
	);
}

// Search content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options_search_content_type',
	array(
		'default'          	=> $options['search_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options_search_content_type',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_search_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_search_section_enable',
		'choices'			=> array( 
				'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
				'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
				'custom' 	=> esc_html__( 'Custom', 'onjob-pro' ),
		),
	)
);

// search pages drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[search_content_page]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_page',
	)
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
	'onjob_pro_theme_options[search_content_page]',
		array(
			'label'             => esc_html__( 'Select Page', 'onjob-pro' ),
			'section'           => 'onjob_pro_search_section',
			'choices'			=> onjob_pro_page_choices(),
			'active_callback'	=> 'onjob_pro_is_search_section_content_page_enable',
		)
	)
);

// search posts drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[search_content_post]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_page',
	)
);

$wp_customize->add_control( new Onjob_Pro_Dropdown_Chooser( $wp_customize,
	'onjob_pro_theme_options[search_content_post]',
		array(
			'label'             => esc_html__( 'Select Post', 'onjob-pro' ),
			'section'           => 'onjob_pro_search_section',
			'choices'			=> onjob_pro_post_choices(),
			'active_callback'	=> 'onjob_pro_is_search_section_content_post_enable',
		)
	)
);


// Search title setting
$wp_customize->add_setting('onjob_pro_theme_options[search_custom_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['search_custom_title']
    )
);

$wp_customize->add_control('onjob_pro_theme_options[search_custom_title]',
    array(
        'section'			=> 'onjob_pro_search_section',
        'label'				=> esc_html__( 'Title:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_if_search_section_content_custom_enable'
    )
);

// Search content setting
$wp_customize->add_setting('onjob_pro_theme_options[search_custom_content]',
    array(
        'sanitize_callback' => 'sanitize_textarea_field',
        'default'           => $options['search_custom_content']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[search_custom_content]',
    array(
        'section'			=> 'onjob_pro_search_section',
        'label'				=> esc_html__( 'Content:', 'onjob-pro' ),
        'type'          	=>'textarea',
        'active_callback'	=> 'onjob_pro_if_search_section_content_custom_enable'
    )
);

// Search Backround image setting
$wp_customize->add_setting('onjob_pro_theme_options[search_custom_image]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'onjob_pro_theme_options[search_custom_image]',
        array(
            'section'			=> 'onjob_pro_search_section',
            'label'				=> esc_html__( 'Search Image:', 'onjob-pro' ),
            'active_callback' 	=> 'onjob_pro_if_search_section_content_custom_enable',
        )
    )
);

//slider_btn_txt
$wp_customize->add_setting('onjob_pro_theme_options[search_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['search_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[search_btn_txt]',
    array(
        'section'			=> 'onjob_pro_search_section',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback' 	=> 'onjob_pro_is_search_section_enable'
    )
);