<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'onjob_pro_service_section', 
	array(
		'title'             => esc_html__( 'Services','onjob-pro' ),
		'description'       => esc_html__( 'Services Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'	=> 'onjob_pro_is_second_design_enable',
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_section_enable]', 
	array(
		'default'			=> 	$options['service_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[service_section_enable]', 
		array(
			'label'             => esc_html__( 'Service Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_service_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		) 
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[service_section_enable]', 
		array(
			'selector'            => '#service-section .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[service_section_enable]',
		) 
	);
}

// Service section sub title control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_section_sub_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_sub_title'],
	) 
);

$wp_customize->add_control('onjob_pro_theme_options[service_section_sub_title]', 
	array(
		'label'             => esc_html__( 'Section Sub Title', 'onjob-pro' ),
		'section'           => 'onjob_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'onjob_pro_is_service_section_enable',
	)
);

$wp_customize->selective_refresh->add_partial('onjob_pro_theme_options[service_section_sub_title]',
    array(
        'selector'            => '#service-section .section-subtitle',
        'render_callback'     => 'onjob_pro_service_section_partial_sub_title',
    )
);

// Service section title control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_section_title]', 
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'transport'			=>'postMessage',
		'default'           => $options['service_section_title'],
		
	) 
);

$wp_customize->add_control('onjob_pro_theme_options[service_section_title]', 
	array(
		'label'             => esc_html__( 'Section Title', 'onjob-pro' ),
		'section'           => 'onjob_pro_service_section',
		'type'              =>'text',
		'active_callback'	=> 'onjob_pro_is_service_section_enable',
	)
);
$wp_customize->selective_refresh->add_partial(
    'onjob_pro_theme_options[service_section_title]',
    array(
        'selector'            => '#service-section .section-title',
        'render_callback'     => 'onjob_pro_service_section_partial_title',
    )
);

// Service content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_content_type]',
	array(
		'default'          	=> $options['service_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	) 
);

$wp_customize->add_control( 'onjob_pro_theme_options[service_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_service_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_service_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
			'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
			'category' 	=> esc_html__( 'Category', 'onjob-pro' ),
		),
	) 
);

// Services post number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_posts_count]', 
	array(
		'default'          	=> $options['service_posts_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_service_posts_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[service_posts_count]', 
	array(
		'label'             => esc_html__( 'Number of Posts', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_service_section',
		'active_callback'   => 'onjob_pro_is_service_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	) 
);

for($i = 1; $i <= $options['service_posts_count']; $i ++):

	
    $wp_customize->add_setting( 'onjob_pro_theme_options[service_icon_' . $i . ']', 
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

	$wp_customize->add_control( new Onjob_Pro_Icon_Picker( $wp_customize,
		'onjob_pro_theme_options[service_icon_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Service Icon %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_service_section',
				'active_callback'	=> 'onjob_pro_is_service_section_enable',
			)
		)
	);

    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[service_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[service_content_page_'.$i.']',
			array(
				'label'             => sprintf(esc_html__( 'Select Page : %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_service_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_service_section_content_page_enable',
			) 
		)
	);

	// service posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[service_content_post_'.$i.']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[service_content_post_'.$i.']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_service_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_service_section_content_post_enable',
			)
		)
	);

    // Onjob_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('onjob_pro_theme_options[service_separator'. $i .']',
		array(
			'sanitize_callback'      => 'onjob_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Onjob_Pro_Customize_Horizontal_Line($wp_customize,
		'onjob_pro_theme_options[service_separator'. $i .']',
			array(
				'active_callback'       => 'onjob_pro_is_service_section_hr_enable',
				'type'                  =>'hr',
				'section'               =>'onjob_pro_service_section',
			)
		)
	);

endfor;

// service category drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[service_category]', 
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[service_category]',
		array(
			'label'             => esc_html__( 'Select Categories', 'onjob-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'onjob_pro_service_section',
			'active_callback'	=> 'onjob_pro_is_service_section_content_category_enable',
		) 
	)
);

// Service Excerpt length setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[service_excerpt_length]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'default'			=> $options['service_excerpt_length'],
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[service_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'onjob-pro' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Service section', 'onjob-pro' ),
		'section'     		=> 'onjob_pro_service_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'onjob_pro_is_service_section_enable',
	)
);

// Latest Posts content setting
$wp_customize->add_setting('onjob_pro_theme_options[service_read_more_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['service_read_more_btn_label']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[service_read_more_btn_label]',
    array(
        'section'			=> 'onjob_pro_service_section',
        'label'				=> esc_html__( 'Read More Button Label', 'onjob-pro' ),
        'type'          	=>'text',
        'active_callback'	=> 'onjob_pro_is_service_section_enable'
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[service_read_more_btn_label]',
        array(
            'selector'            => '#service-section div.read-more a',
            'settings'            => 'onjob_pro_theme_options[service_read_more_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'onjob_pro_service_read_more_btn_label_partial',
        ) 
    );
}
