<?php
/**
 * Sponsor Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Sponsor section
$wp_customize->add_section( 'onjob_pro_sponsor_section',
	array(
		'title'             => esc_html__( 'Sponsor','onjob-pro' ),
		'description'       => esc_html__( 'Sponsor Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
        'active_callback' 	=> 'onjob_pro_is_fourth_design_disable',
	)
);

// Sponsor content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_section_enable]', 
	array(
		'default'			=> 	$options['sponsor_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[sponsor_section_enable]',
		array(
			'label'             => esc_html__( 'Sponsor Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_sponsor_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Sponsor number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_count]',
	array(
		'default'          	=> $options['sponsor_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_sponsor_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[sponsor_count]',
	array(
		'label'             => esc_html__( 'Number of Post', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 1 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_sponsor_section',
		'active_callback'   => 'onjob_pro_is_sponsor_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 1,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
	)
);

// Sponsor content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_content_type]',
	array(
		'default'          	=> $options['sponsor_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[sponsor_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_sponsor_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_sponsor_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
			'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
			'category' 	=> esc_html__( 'Category', 'onjob-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'onjob-pro' ),
		),
	)
);


for ( $i = 1; $i <= $options['sponsor_count']; $i++ ) :

	// sponsor pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_content_page_'. $i .']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[sponsor_content_page_'. $i .']', 
			array(
				'label'             => sprintf(esc_html__( 'Select Page: %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_sponsor_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_sponsor_section_content_page_enable',
			)
		)
	);

	// sponsor posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_content_post_'. $i .']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[sponsor_content_post_'. $i .']',
			array(
				'label'             => sprintf(esc_html__( 'Select Post : %d', 'onjob-pro'), $i ),
				'section'           => 'onjob_pro_sponsor_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_sponsor_section_content_post_enable',
			)
		)
	);

	// Onjob_Pro_Customize_Horizontal_Line
    $wp_customize->add_setting('onjob_pro_theme_options[sponsor_separator'. $i .']',
		array(
			'sanitize_callback'      => 'onjob_pro_sanitize_html',
		)
	);

    $wp_customize->add_control(new Onjob_Pro_Customize_Horizontal_Line($wp_customize,
		'onjob_pro_theme_options[sponsor_separator'. $i .']',
			array(
				'active_callback'       => 'onjob_pro_is_sponsor_section_separator_enable',
				'type'                  =>'hr',
				'section'               =>'onjob_pro_sponsor_section',
			)
		)
	);

        
    // About image setting
    $wp_customize->add_setting('onjob_pro_theme_options[sponsor_image_'.$i.']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_image',
		)
	);

    $wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
		'onjob_pro_theme_options[sponsor_image_'.$i.']',
			array(
				'section'			=> 'onjob_pro_sponsor_section',
				'label'				=> esc_html__( 'Image:', 'onjob-pro' ),
				'active_callback' 	=> 'onjob_pro_is_sponsor_section_content_custom_enable',
			)
		)
	);

            
    $wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_url_'.$i.']',
        array(
            'sanitize_callback' => 'esc_url_raw',
        )
    );

    $wp_customize->add_control( 'onjob_pro_theme_options[sponsor_url_'.$i.']',
        array(
			'label'             => sprintf(esc_html__( 'Sponsor URL : %d', 'onjob-pro'), $i ),
            'section'        	=> 'onjob_pro_sponsor_section',
            'active_callback' 	=> 'onjob_pro_is_sponsor_section_content_custom_enable',
            'type'				=> 'url',
        ) 
    );


endfor;

// sponsor posts drop down chooser control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[sponsor_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[sponsor_category]', 
		array(
			'label'             => esc_html__( 'Select Categories', 'onjob-pro' ),
			'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'type'           	=> 'dropdown-taxonomies',
			'section'           => 'onjob_pro_sponsor_section',
			'active_callback'	=> 'onjob_pro_is_sponsor_section_content_category_enable',
		)
	)
); 

