<?php
/**
 * Subscription Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Subscription section
$wp_customize->add_section('onjob_pro_subscription_section',
    array(
        'title'         => esc_html__( 'Subscription', 'onjob-pro' ),
        'description'   => sprintf( esc_html__( '%1$sJetpack%2$s should be active and site should be connected to WordPress.com for this section to work.', 'onjob-pro' ), '<a target="_blank" href="https://wordpress.org/plugins/jetpack">', '</a>' ),
        'panel'         => 'onjob_pro_front_page_panel',
        'active_callback'   => 'onjob_pro_is_fourth_design_disable',

    )
);

// Subscription enable setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_section_enable]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
        'default'           => $options['subscription_section_enable'],
    )
);

$wp_customize->add_control(new Onjob_Pro_Switch_Control($wp_customize,
    'onjob_pro_theme_options[subscription_section_enable]',
        array(
            'section'		=> 'onjob_pro_subscription_section',
            'label'			=> esc_html__( 'Enable subscription.', 'onjob-pro' ),
            'on_off_label'  => onjob_pro_switch_options(),
        )
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[subscription_section_enable]',
        array(
            'selector'            => '#subscribe-us .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[subscription_section_enable]',
        )
    );
}

// Subscription Backround image setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_bg_image]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'onjob_pro_theme_options[subscription_bg_image]',
        array(
            'section'			=> 'onjob_pro_subscription_section',
            'label'				=> esc_html__( 'Background Image:', 'onjob-pro' ),
            'active_callback' 	=> 'onjob_pro_is_subscription_section_enable',
        )
    )
);

// Subscribe title setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_section_policy]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_policy'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[subscription_section_policy]',
    array(
        'section'		    => 'onjob_pro_subscription_section',
        'label'			    => esc_html__( 'Subscription Policy', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_subscription_section_enable',
        'type'              => 'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[subscription_section_policy]',
		array(
			'selector'            => '#subscribe-us div.subscribe-form-wrapper p#policy',
			'settings'            => 'onjob_pro_theme_options[subscription_section_policy]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_subscription_section_policy_partial',
		) 
	);
}

// Subscribe title setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[subscription_section_title]',
    array(
        'section'		    => 'onjob_pro_subscription_section',
        'label'			    => esc_html__( 'Section Title:', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_subscription_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[subscription_section_title]',
		array(
			'selector'            => '#subscribe-us div.subscribe-form-wrapper h2.widgettitle',
			'settings'            => 'onjob_pro_theme_options[subscription_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_subscription_section_title_partial',
		) 
	);
}

// Subscribe text setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_section_description]',
    array(
        'sanitize_callback' => 'wp_kses_post',
        'default'           => $options['subscription_section_description'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[subscription_section_description]',
    array(
        'section'		    => 'onjob_pro_subscription_section',
        'label'			    => esc_html__( 'Description:', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_subscription_section_enable',
        'type'			    => 'textarea'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[subscription_section_description]',
		array(
			'selector'            => '#subscribe-us div.subscribe-form-wrapper #subscribe-text p',
			'settings'            => 'onjob_pro_theme_options[subscription_section_description]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_subscription_section_description_partial',
		) 
	);
}

// Subscribe button text setting
$wp_customize->add_setting('onjob_pro_theme_options[subscription_section_btn_txt]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['subscription_section_btn_txt'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[subscription_section_btn_txt]',
    array(
        'section'		    => 'onjob_pro_subscription_section',
        'label'			    => esc_html__( 'Button text:', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_subscription_section_enable'
    )
);
    
// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[subscription_section_btn_txt]',
        array(
            'selector'            => '#subscribe-us div.subscribe-form-wrapper #subscribe-submit button',
            'settings'            => 'onjob_pro_theme_options[subscription_section_btn_txt]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'onjob_pro_subscription_section_btn_txt_partial',
        ) 
    );
}