<?php
/**
 * Team Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Team section
$wp_customize->add_section( 'onjob_pro_team_section',
	array(
		'title'             => esc_html__( 'Team','onjob-pro' ),
		'description'       => esc_html__( 'Team Section options.', 'onjob-pro' ),
		'panel'             => 'onjob_pro_front_page_panel',
		'active_callback' 	=> 'onjob_pro_is_second_design_enable',
	)
);

// Team content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[team_section_enable]',
	array(
		'default'			=> 	$options['team_section_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[team_section_enable]',
		array(
			'label'             => esc_html__( 'Team Section Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_team_section',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[team_section_enable]',
		array(
			'selector'            => '#team-section .tooltiptext',
			'settings'            => 'onjob_pro_theme_options[team_section_enable]',
		)
	);
}

// team title setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[team_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['team_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[team_title]',
	array(
		'label'           	=> esc_html__( 'Section Title', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_team_section',
		'active_callback' 	=> 'onjob_pro_is_team_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[team_title]',
		array(
			'selector'            => '#team-section .section-header h2',
			'settings'            => 'onjob_pro_theme_options[team_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'onjob_pro_team_title_partial',
		)
	);
}

// team description setting and control
$wp_customize->add_setting( 'onjob_pro_theme_options[team_sub_title]',
	array(
		'sanitize_callback' => 'sanitize_text_field',
		'default'			=> $options['team_sub_title'],
		'transport'			=> 'postMessage',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[team_sub_title]',
	array(
		'label'           	=> esc_html__( 'Section Sub Title', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_team_section',
		'active_callback' 	=> 'onjob_pro_is_team_section_enable',
		'type'				=> 'text',
	)
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[team_sub_title]',
		array(
			'selector'            => '#team-section .section-header p',
			'settings'            => 'onjob_pro_theme_options[team_sub_title]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'onjob_pro_team_sub_title_partial',
		)
	);
}


// Slider number control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[team_count]',
	array(
		'default'          	=> $options['team_count'],
		'sanitize_callback' => 'onjob_pro_sanitize_number_range',
		'validate_callback' => 'onjob_pro_validate_team_count',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[team_count]',
	array(
		'label'             => esc_html__( 'Number of Featured', 'onjob-pro' ),
		'description'       => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
		'section'           => 'onjob_pro_team_section',
		'active_callback'   => 'onjob_pro_is_team_section_enable',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 12,
			'style' => 'width: 100px;'
		),
	)
);

// team content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[team_column]',
	array(
		'default'          	=> $options['team_column'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[team_column]',
	array(
		'label'             => esc_html__( 'Column Layout', 'onjob-pro' ),
		'section'           => 'onjob_pro_team_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_team_section_enable',
		'choices'			=> array( 
			'col-2'		=> esc_html__( 'Two Column', 'onjob-pro' ),
			'col-3'		=> esc_html__( 'Three Column', 'onjob-pro' ),
			'col-4'		=> esc_html__( 'Four Column', 'onjob-pro' ),
		),
	)
);

// Team content type control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[team_content_type]',
	array(
		'default'          	=> $options['team_content_type'],
		'sanitize_callback' => 'onjob_pro_sanitize_select',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[team_content_type]',
	array(
		'label'             => esc_html__( 'Content Type', 'onjob-pro' ),
		'section'           => 'onjob_pro_team_section',
		'type'				=> 'select',
		'active_callback' 	=> 'onjob_pro_is_team_section_enable',
		'choices'			=> array( 
			'page' 		=> esc_html__( 'Page', 'onjob-pro' ),
			'post' 		=> esc_html__( 'Post', 'onjob-pro' ),
			'category' 	=> esc_html__( 'Category', 'onjob-pro' ),
			'custom' 	=> esc_html__( 'Custom', 'onjob-pro' ),
		),
	)
);

// Add dropdown category setting and control.
$wp_customize->add_setting(  'onjob_pro_theme_options[team_content_category]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_single_category',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Dropdown_Taxonomies_Control( $wp_customize,
	'onjob_pro_theme_options[team_content_category]',
		array(
			'label'             => esc_html__( 'Select Category', 'onjob-pro' ),
			'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'onjob-pro' ),
			'section'           => 'onjob_pro_team_section',
			'type'              => 'dropdown-taxonomies',
			'active_callback'	=> 'onjob_pro_is_team_section_content_category_enable'
		)
	)
);

for ( $i = 1; $i <= $options['team_count']; $i++ ) :

	// team pages drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_content_page_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[team_content_page_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Page %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_team_section',
				'choices'			=> onjob_pro_page_choices(),
				'active_callback'	=> 'onjob_pro_is_team_section_content_page_enable',
			)
		)
	);

	// team posts drop down chooser control and setting
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_content_post_' . $i . ']', 
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_page',
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Dropdown_Chooser( $wp_customize,
		'onjob_pro_theme_options[team_content_post_' . $i . ']',
			array(
				'label'             => sprintf( esc_html__( 'Select Post %d', 'onjob-pro' ), $i ),
				'section'           => 'onjob_pro_team_section',
				'choices'			=> onjob_pro_post_choices(),
				'active_callback'	=> 'onjob_pro_is_team_section_content_post_enable',
			)
		)
	);

	// team title setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_title_' . $i . ']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[team_title_' . $i . ']',
		array(
			'label'           	=> sprintf( esc_html__( 'Title %d', 'onjob-pro' ), $i ),
			'section'        	=> 'onjob_pro_team_section',
			'active_callback' 	=> 'onjob_pro_is_team_section_content_custom_enable',
			'type'				=> 'text',
		)
	);

	// team position setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_position_' . $i . ']',
		array(
			'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[team_position_' . $i . ']',
		array(
			'label'           	=> sprintf( esc_html__( 'Position %d', 'onjob-pro' ), $i ),
			'section'        	=> 'onjob_pro_team_section',
			'active_callback' 	=> 'onjob_pro_is_team_section_enable',
			'type'				=> 'text',
		)
	);

	// team image setting and control.
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_image_' . $i . ']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_image'
		)
	);

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
		'onjob_pro_theme_options[team_image_' . $i . ']',
			array(
				'label'       		=> sprintf( esc_html__( 'Image %d', 'onjob-pro' ), $i ),
				'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'onjob-pro' ), 382, 420 ),
				'section'     		=> 'onjob_pro_team_section',
				'active_callback'	=> 'onjob_pro_is_team_section_content_custom_enable',
			)
		)
	);

	// team position setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_link_' . $i . ']',
		array(
			'sanitize_callback' => 'esc_url_raw',
		)
	);

	$wp_customize->add_control( 'onjob_pro_theme_options[team_link_' . $i . ']',
		array(
			'label'           	=> sprintf( esc_html__( 'URL Link %d', 'onjob-pro' ), $i ),
			'section'        	=> 'onjob_pro_team_section',
			'active_callback' 	=> 'onjob_pro_is_team_section_content_custom_enable',
			'type'				=> 'url',
		)
	);
	

	// team multiple input setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_social_'. $i .']',
		array(
			'sanitize_callback' => 'sanitize_text_field'
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Multi_Input_Custom_Control( $wp_customize,
		'onjob_pro_theme_options[team_social_'. $i .']',
			array(
				'label'           => sprintf( esc_html__( 'Social Link %d', 'onjob-pro' ), $i ),
				'button_text'	  => esc_html__( 'Add Social Link', 'onjob-pro' ),
				'section'         => 'onjob_pro_team_section',
				'active_callback' => 'onjob_pro_is_team_section_enable',
				'type'			  => 'multi-input'
			)
		)
	);

	// team hr setting and control
	$wp_customize->add_setting( 'onjob_pro_theme_options[team_hr_'. $i .']',
		array(
			'sanitize_callback' => 'onjob_pro_sanitize_html'
		)
	);

	$wp_customize->add_control( new  Onjob_Pro_Customize_Horizontal_Line( $wp_customize,
		'onjob_pro_theme_options[team_hr_'. $i .']',
			array(
				'section'         => 'onjob_pro_team_section',
				'active_callback' => 'onjob_pro_is_team_section_enable',
				'type'			  => 'hr'
			)
		)
	);

endfor;