<?php

/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section('onjob_pro_testimonial_section',
    array(
        'title'             => esc_html__('Testimonials', 'onjob-pro'),
        'description'       => esc_html__('Testimonials Section options.', 'onjob-pro'),
        'panel'             => 'onjob_pro_front_page_panel',
        'active_callback'   => 'onjob_pro_is_fourth_design_disable',

    )
);

// Testimonial content enable control and setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_section_enable]',
    array(
        'default'           => $options['testimonial_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control(new  Onjob_Pro_Switch_Control($wp_customize,
    'onjob_pro_theme_options[testimonial_section_enable]',
        array(
            'label'         => esc_html__('Testimonial Section Enable', 'onjob-pro'),
            'section'       => 'onjob_pro_testimonial_section',
            'on_off_label'  => onjob_pro_switch_options(),
        )
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[testimonial_section_enable]',
        array(
            'selector'            => '#testimonial-section .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[testimonial_section_enable]',
        )
    );
}


// Testimonial autoplay enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[testimonial_autoplay_enable]',
	array(
		'default'			=> 	$options['testimonial_autoplay_enable'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[testimonial_autoplay_enable]',
		array(
			'label'             => esc_html__( 'Testimonial Autoplay Enable', 'onjob-pro' ),
			'section'           => 'onjob_pro_testimonial_section',
			'active_callback'   => 'onjob_pro_is_testimonial_section_enable',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Testimonial section sub title control and setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_section_sub_title]',
    array(
        'sanitize_callback'     => 'sanitize_text_field',
        'transport'             => 'postMessage',
        'default'               => $options['testimonial_section_sub_title'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[testimonial_section_sub_title]',
    array(
        'label'             => esc_html__('Section Sub Title', 'onjob-pro'),
        'section'           => 'onjob_pro_testimonial_section',
        'type'              => 'text',
        'active_callback'   => 'onjob_pro_is_testimonial_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('onjob_pro_theme_options[testimonial_section_sub_title]',
    array(
        'selector'          => '#testimonial-section .section-subtitle',
        'render_callback'   => 'onjob_pro_testimonial_section_partial_sub_title',
    )
);

// Testimonial section title control and setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_section_title]',
    array(
        'default'               => $options['testimonial_section_title'],
        'sanitize_callback'     => 'sanitize_text_field',
        'transport'             => 'postMessage'
    )
);

$wp_customize->add_control('onjob_pro_theme_options[testimonial_section_title]',
    array(
        'label'                 => esc_html__('Section Title', 'onjob-pro'),
        'section'               => 'onjob_pro_testimonial_section',
        'type'                  => 'text',
        'active_callback'       => 'onjob_pro_is_testimonial_section_enable',
    )
);

$wp_customize->selective_refresh->add_partial('onjob_pro_theme_options[testimonial_section_title]',
    array(
        'selector'          => '#testimonial-section .section-title',
        'render_callback'   => 'onjob_pro_testimonial_section_partial_title',
    )
);

//Testimonial section content control type setting and control
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_content_type]',
    array(
        'default'               => $options['testimonial_content_type'],
        'sanitize_callback'     => 'onjob_pro_sanitize_select',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[testimonial_content_type]',
    array(
        'label'                 => esc_html__('Content Type', 'onjob-pro'),
        'section'               => 'onjob_pro_testimonial_section',
        'type'                  => 'select',
        'active_callback'       => 'onjob_pro_is_testimonial_section_enable',
        'choices'               => array(
            'page'      => esc_html__('Page', 'onjob-pro'),
            'post'      => esc_html__('Post', 'onjob-pro'),
            'category'  => esc_html__('Category', 'onjob-pro'),
        ),
    )
);


// Testimonial post number control and setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_posts_count]',
    array(
        'default'               => $options['testimonial_posts_count'],
        'sanitize_callback'     => 'onjob_pro_sanitize_number_range',
		'validate_callback'     => 'onjob_pro_validate_testimonial_count',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[testimonial_posts_count]',
    array(
        'label'                 => esc_html__('Number of Posts', 'onjob-pro'),
		'description'           => esc_html__( 'Note: Min 3 & Max 6. Please input the valid number and save. Then refresh the page to see the change.', 'onjob-pro' ),
        'section'               => 'onjob_pro_testimonial_section',
        'active_callback'       => 'onjob_pro_is_testimonial_section_enable',
        'type'                  => 'number',
        'input_attrs'		=> array(
			'min'	=> 3,
			'max'	=> 6,
			'style' => 'width: 100px;'
		),
    )
);

for ($i = 1; $i <= $options['testimonial_posts_count']; $i++):

    // Testimonial pages drop down chooser control and setting
    $wp_customize->add_setting('onjob_pro_theme_options[testimonial_content_page_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Onjob_Pro_Dropdown_Chooser($wp_customize,
        'onjob_pro_theme_options[testimonial_content_page_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Page : %d', 'onjob-pro'), $i),
                'section'           => 'onjob_pro_testimonial_section',
                'choices'           => onjob_pro_page_choices(),
                'active_callback'   => 'onjob_pro_is_testimonial_section_content_page_enable',
            )
        )
    );

    // Testimonial posts drop down chooser control and setting
    $wp_customize->add_setting('onjob_pro_theme_options[testimonial_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'onjob_pro_sanitize_page',
        )
    );

    $wp_customize->add_control(new  Onjob_Pro_Dropdown_Chooser($wp_customize,
        'onjob_pro_theme_options[testimonial_content_post_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Post : %d', 'onjob-pro'), $i),
                'section'           => 'onjob_pro_testimonial_section',
                'choices'           => onjob_pro_post_choices(),
                'active_callback'   => 'onjob_pro_is_testimonial_section_content_post_enable',
            )
        )
    );

    // Testimonial posts sub title control and setting
    $wp_customize->add_setting('onjob_pro_theme_options[testimonial_post_designation_' . $i . ']',
        array(
            'sanitize_callback' => 'sanitize_text_field',
        )
    );

    $wp_customize->add_control(new  Onjob_Pro_Dropdown_Chooser($wp_customize,
        'onjob_pro_theme_options[testimonial_post_designation_' . $i . ']',
            array(
                'label'             => sprintf(esc_html__('Select Designation : %d', 'onjob-pro'), $i),
                'section'           => 'onjob_pro_testimonial_section',
                'active_callback'   => 'onjob_pro_is_testimonial_section_enable',
                'type'              => 'text',
            )
        )
    );

    //testimonial separator
    $wp_customize->add_setting('onjob_pro_theme_options[testimonial_separator'. $i .']',
        array(
            'sanitize_callback'      => 'onjob_pro_sanitize_html',
        )
    );

    $wp_customize->add_control(new  Onjob_Pro_Customize_Horizontal_Line($wp_customize,
        'onjob_pro_theme_options[testimonial_separator'. $i .']',
            array(
                'active_callback'       => 'onjob_pro_is_testimonial_section_enable',
                'type'                  =>'hr',
                'section'               =>'onjob_pro_testimonial_section',
            )
        )
    );

endfor;

// Testimonial category drop down chooser control and setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_category]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_single_category',
    )
);

$wp_customize->add_control(new  Onjob_Pro_Dropdown_Taxonomies_Control($wp_customize,
    'onjob_pro_theme_options[testimonial_category]',
        array(
            'label'             => esc_html__('Select Categories', 'onjob-pro'),
            'description'       => esc_html__('Note: Latest selected no of posts will be shown from selected category', 'onjob-pro'),
            'type'              => 'dropdown-taxonomies',
            'section'           => 'onjob_pro_testimonial_section',
            'active_callback'   => 'onjob_pro_is_testimonial_section_content_category_enable',
        )
    )
);


// testimonial Background image setting
$wp_customize->add_setting('onjob_pro_theme_options[testimonial_bg_image]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'onjob_pro_theme_options[testimonial_bg_image]',
        array(
            'section'			=> 'onjob_pro_testimonial_section',
            'label'				=> esc_html__( 'Background Image:', 'onjob-pro' ),
            'active_callback' 	=> 'onjob_pro_is_testimonial_section_enable',
        )
    )
);
