<?php
/**
 * Video Section options
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */

// Add Video section
$wp_customize->add_section( 'onjob_pro_video_section',
    array(
        'title'             => esc_html__( 'Video','onjob-pro' ),
        'description'       => esc_html__( 'Video Section options.', 'onjob-pro' ),
        'panel'             => 'onjob_pro_front_page_panel',
		'active_callback'   => 'onjob_pro_is_second_design_enable',

    )
);

// Video content enable control and setting
$wp_customize->add_setting( 'onjob_pro_theme_options[video_section_enable]',
    array(
        'default'           =>  $options['video_section_enable'],
        'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Onjob_Pro_Switch_Control( $wp_customize,
    'onjob_pro_theme_options[video_section_enable]',
        array(
            'label'             => esc_html__( 'Video Section Enable', 'onjob-pro' ),
            'section'           => 'onjob_pro_video_section',
            'on_off_label'      => onjob_pro_switch_options(),
        ) 
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) { 
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[video_section_enable]',
        array(
            'selector'            => '#blog-latest-posts .tooltiptext',
            'settings'            => 'onjob_pro_theme_options[video_section_enable]',
        )
    );
}


// Video Backround image setting
$wp_customize->add_setting('onjob_pro_theme_options[video_bg_image]',
    array(
        'sanitize_callback' => 'onjob_pro_sanitize_image',
    )
);

$wp_customize->add_control(new WP_Customize_Image_Control( $wp_customize,
    'onjob_pro_theme_options[video_bg_image]',
        array(
            'section'			=> 'onjob_pro_video_section',
            'label'				=> esc_html__( 'Background Image:', 'onjob-pro' ),
            'active_callback' 	=> 'onjob_pro_is_video_section_enable',
        )
    )
);

// Subscribe title setting
$wp_customize->add_setting('onjob_pro_theme_options[video_section_sub_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['video_section_sub_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[video_section_sub_title]',
    array(
        'section'		    => 'onjob_pro_video_section',
        'label'			    => esc_html__( 'Section Sub Title:', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_video_section_enable',
        'type'              => 'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[video_section_sub_title]',
		array(
			'selector'            => '#video-section p.section-subtitle',
			'settings'            => 'onjob_pro_theme_options[video_section_sub_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_video_section_sub_title_partial',
		) 
	);
}

// Subscribe title setting
$wp_customize->add_setting('onjob_pro_theme_options[video_section_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['video_section_title'],
        'transport'	        => 'postMessage',
    )
);

$wp_customize->add_control('onjob_pro_theme_options[video_section_title]',
    array(
        'section'		    => 'onjob_pro_video_section',
        'label'			    => esc_html__( 'Section Title:', 'onjob-pro' ),
        'active_callback'   => 'onjob_pro_is_video_section_enable',
        'type'              =>'text'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[video_section_title]',
		array(
			'selector'            => '#video-section h2.section-title',
			'settings'            => 'onjob_pro_theme_options[video_section_title]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_video_section_title_partial',
		) 
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[video_id]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[video_id]',
    array(
        'label'           	=> esc_html__( 'Video URL', 'onjob-pro' ),
        'description'       => esc_html__( 'Note: Input video code from youtube. eg. https://www.youtube.com/watch?v=sXPmLE_KELo code after v "sXPmLE_KELo"', 'onjob-pro' ),
        'section'        	=> 'onjob_pro_video_section',
        'active_callback' 	=> 'onjob_pro_is_video_section_enable',
        'type'				=> 'text',
    ) 
);
