<?php
/**
 * Footer options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Footer Section
$wp_customize->add_section( 'onjob_pro_section_footer',
	array(
		'title'      			=> esc_html__( 'Footer Options', 'onjob-pro' ),
		'priority'   			=> 900,
		'panel'      			=> 'onjob_pro_theme_options_panel',
	)
);

// footer text
$wp_customize->add_setting( 'onjob_pro_theme_options[copyright_text]',
	array(
		'default'       		=> $options['copyright_text'],
		'sanitize_callback'		=> 'onjob_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[copyright_text]',
    array(
		'label'      			=> esc_html__( 'Copyright Text', 'onjob-pro' ),
		'section'    			=> 'onjob_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[copyright_text]',
		array(
			'selector'            => '#colophon div.site-info > div > span.copyright-text',
			'settings'            => 'onjob_pro_theme_options[copyright_text]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'onjob_pro_copyright_text_partial',
		)
	);
}

// footer text
$wp_customize->add_setting( 'onjob_pro_theme_options[theme_credit]',
	array(
		'default'       		=> $options['theme_credit'],
		'sanitize_callback'		=> 'onjob_pro_santize_allow_tag',
		'transport'				=> 'postMessage',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[theme_credit]',
    array(
		'label'      			=> esc_html__( 'Theme Credit', 'onjob-pro' ),
		'section'    			=> 'onjob_pro_section_footer',
		'type'		 			=> 'textarea',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[theme_credit]',
		array(
			'selector'            => '#colophon div.site-info > div > span.theme-credit',
			'settings'            => 'onjob_pro_theme_options[theme_credit]',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'onjob_pro_theme_credit_partial',
		)
	);
}

// scroll top visible
$wp_customize->add_setting( 'onjob_pro_theme_options[scroll_top_visible]',
	array(
		'default'       	=> $options['scroll_top_visible'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[scroll_top_visible]',
		array(
			'label'      		=> esc_html__( 'Display Scroll Top Button', 'onjob-pro' ),
			'section'    		=> 'onjob_pro_section_footer',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);


// scroll top visible
$wp_customize->add_setting( 'onjob_pro_theme_options[enable_footer_search]',
	array(
		'default'       	=> $options['enable_footer_search'],
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[enable_footer_search]',
		array(
			'label'      		=> esc_html__( 'Footer Search Enable', 'onjob-pro' ),
			'section'    		=> 'onjob_pro_section_footer',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

// Blog content setting
$wp_customize->add_setting('onjob_pro_theme_options[footer_search_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['footer_search_title']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[footer_search_title]',
    array(
        'section'			=> 'onjob_pro_section_footer',
        'label'				=> esc_html__( 'Search Title', 'onjob-pro' ),
        'type'          	=> 'text',
        'active_callback'	=> 'onjob_pro_is_footer_search_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[footer_search_title]',
        array(
            'selector'            => '#colophon div.search-jobs header.entry-header > h2',
            'settings'            => 'onjob_pro_theme_options[footer_search_title]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'onjob_pro_footer_search_title_partial',
        ) 
    );
}

// Blog content setting
$wp_customize->add_setting('onjob_pro_theme_options[footer_search_placeholder]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['footer_search_placeholder']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[footer_search_placeholder]',
    array(
        'section'			=> 'onjob_pro_section_footer',
        'label'				=> esc_html__( 'Placeholder Label', 'onjob-pro' ),
        'type'          	=> 'text',
        'active_callback'	=> 'onjob_pro_is_footer_search_enable'
    )
);

// Blog content setting
$wp_customize->add_setting('onjob_pro_theme_options[footer_search_button_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['footer_search_button_label']

    )
);

$wp_customize->add_control('onjob_pro_theme_options[footer_search_button_label]',
    array(
        'section'			=> 'onjob_pro_section_footer',
        'label'				=> esc_html__( 'Button Label', 'onjob-pro' ),
        'type'          	=> 'text',
        'active_callback'	=> 'onjob_pro_is_footer_search_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[footer_search_button_label]',
        array(
            'selector'            => '#colophon div.search-jobs form#searchform button',
            'settings'            => 'onjob_pro_theme_options[footer_search_button_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'onjob_pro_footer_search_button_label_partial',
        ) 
    );
}