<?php
/**
 * Menu options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

// Add sidebar section
$wp_customize->add_section( 'onjob_pro_menu',
	array(
		'title'             => esc_html__('Header Menu','onjob-pro'),
		'description'       => esc_html__( 'Header Menu options.', 'onjob-pro' ),
		'panel'             => 'nav_menus',
	)
);

// Menu sticky setting and control.
$wp_customize->add_setting( 'onjob_pro_theme_options[menu_sticky]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
		'default'           => $options['menu_sticky'],
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[menu_sticky]',
		array(
			'label'             => esc_html__( 'Make Menu Sticky', 'onjob-pro' ),
			'section'           => 'onjob_pro_menu',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

$wp_customize->add_setting( 'onjob_pro_theme_options[search_icon_in_primary_menu_enable]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_switch_control',
		'default'           => $options['search_icon_in_primary_menu_enable'],
	)
);

$wp_customize->add_control( new  Onjob_Pro_Switch_Control( $wp_customize,
	'onjob_pro_theme_options[search_icon_in_primary_menu_enable]',
		array(
			'label'             => esc_html__( 'Show Search Icon in Primary menu', 'onjob-pro' ),
			'section'           => 'onjob_pro_menu',
			'on_off_label' 		=> onjob_pro_switch_options(),
		)
	)
);

$wp_customize->add_setting( 'onjob_pro_theme_options[ads_image_in_menu]',
	array(
		'sanitize_callback' => 'onjob_pro_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'onjob_pro_theme_options[ads_image_in_menu]',
		array(
			'label'       		=> esc_html__( 'Advertisement Image', 'onjob-pro' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'onjob-pro' ), 1350, 385 ),
			'section'     		=> 'onjob_pro_menu',
			'active_callback'	=> 'onjob_pro_is_fourth_design_enable',

		) 
	)
);

$wp_customize->add_setting( 'onjob_pro_theme_options[ads_image_in_menu_url]',
    array(
        'sanitize_callback' => 'esc_url_raw',
    )
);

$wp_customize->add_control( 'onjob_pro_theme_options[ads_image_in_menu_url]',
    array(
        'label'           	=> esc_html__( 'Advertisement URL', 'onjob-pro' ),
        'section'        	=> 'onjob_pro_menu',
        'type'				=> 'url',
		'active_callback'	=> 'onjob_pro_is_fourth_design_enable',

    ) 
);

//primary_menu_label1
$wp_customize->add_setting('onjob_pro_theme_options[primary_menu_label1]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['primary_menu_label1'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[primary_menu_label1]',
    array(
        'section'			=> 'onjob_pro_menu',
        'label'				=> esc_html__( 'Menu 1 Label:', 'onjob-pro' ),
        'type'          	=>'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[primary_menu_label1]',
		array(
			'selector'            => '#site-navigation ul.register-menu > li:nth-child(1) a',
			'settings'            => 'onjob_pro_theme_options[primary_menu_label1]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_primary_menu_label1_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[primary_menu_label1_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[primary_menu_label1_url]',
	array(
		'label'           	=>  esc_html__( 'Menu Label 1 Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_menu',
		'type'				=> 'url',
	)
);

//primary_menu_label1
$wp_customize->add_setting('onjob_pro_theme_options[primary_menu_label2]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['primary_menu_label2'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[primary_menu_label2]',
    array(
        'section'			=> 'onjob_pro_menu',
        'label'				=> esc_html__( 'Menu 2 Label:', 'onjob-pro' ),
        'type'          	=>'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[primary_menu_label2]',
		array(
			'selector'            => '#site-navigation ul.register-menu > li:nth-child(2) a',
			'settings'            => 'onjob_pro_theme_options[primary_menu_label2]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_primary_menu_label2_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[primary_menu_label2_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[primary_menu_label2_url]',
	array(
		'label'           	=>  esc_html__( 'Menu Label 2 Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_menu',
		'type'				=> 'url',
	)
);

//primary_menu_button
$wp_customize->add_setting('onjob_pro_theme_options[primary_menu_button]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['primary_menu_button'],
    )
);

$wp_customize->add_control('onjob_pro_theme_options[primary_menu_button]',
    array(
        'section'			=> 'onjob_pro_menu',
        'label'				=> esc_html__( 'Button Text:', 'onjob-pro' ),
        'type'          	=>'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'onjob_pro_theme_options[primary_menu_button]',
		array(
			'selector'            => '.main-navigation .register-menu li.custom-button a',
			'settings'            => 'onjob_pro_theme_options[primary_menu_button]',
			'fallback_refresh'    => true,
			'container_inclusive' => false,
			'render_callback'     => 'onjob_pro_primary_menu_button_partial',
		)
	);
}

$wp_customize->add_setting( 'onjob_pro_theme_options[primary_menu_button_url]',
	array(
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control( 'onjob_pro_theme_options[primary_menu_button_url]',
	array(
		'label'           	=>  esc_html__( 'Button Link ', 'onjob-pro' ),
		'section'        	=> 'onjob_pro_menu',
		'type'				=> 'url',
	)
);
