<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function onjob_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function onjob_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of jobs for post choices.
 * @return Array Array of post ids and name.
 */
function onjob_pro_job_listing_choices() {
    $posts = get_posts( array( 'post_type' => 'job_listing', 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


/**
 * List of products for post choices.
 * @return Array Array of post ids and name.
 */
function onjob_pro_product_choices() {
    $posts = get_posts( array( 'numberposts' => -1, 'post_type' => 'product' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function onjob_pro_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
        'hide_empty' => false,
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}
/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function onjob_pro_job_category_choices() {
    if(!taxonomy_exists('job_listing_category')) return;
    $tax_args = array(
        'hide_empty' => false,
        'hierarchical' => 0,
        'taxonomy'     => 'job_listing_category',
    );
    $taxonomies = get_terms( $tax_args );
    $choices = array();
    if(!is_wp_error($taxonomies) && $taxonomies != NULL ){
        $choices[0] = esc_html__( '--Select--', 'onjob-pro' );
        foreach ( $taxonomies as $tax ) {
            $choices[ $tax->term_id ] = $tax->name;
        }
    }
    return  $choices;
}




if ( ! function_exists( 'onjob_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function onjob_pro_site_layout() {
        $onjob_pro_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'boxed-layout'  => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
            'frame-layout'  => esc_url( get_template_directory_uri() . '/assets/images/framed.png' ),
        );

        $output = apply_filters( 'onjob_pro_site_layout', $onjob_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'onjob_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function onjob_pro_selected_sidebar() {
        $onjob_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'onjob-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'onjob-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'onjob-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'onjob-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'onjob-pro' ),
        );

        $output = apply_filters( 'onjob_pro_selected_sidebar', $onjob_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'onjob_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function onjob_pro_global_sidebar_position() {
        $onjob_pro_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'  => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'onjob_pro_global_sidebar_position', $onjob_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'onjob_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function onjob_pro_sidebar_position() {
        $onjob_pro_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'left-sidebar'          => esc_url( get_template_directory_uri() . '/assets/images/left.png' ),
            'no-sidebar'            => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'no-sidebar-content'    => esc_url( get_template_directory_uri() . '/assets/images/boxed.png' ),
        );

        $output = apply_filters( 'onjob_pro_sidebar_position', $onjob_pro_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'onjob_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function onjob_pro_pagination_options() {
        $onjob_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'onjob-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'onjob-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'onjob-pro' ),
        );

        $output = apply_filters( 'onjob_pro_pagination_options', $onjob_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'onjob_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function onjob_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'onjob-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'onjob-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'onjob-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'onjob-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'onjob-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'onjob-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'onjob-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'onjob-pro' ),
        );
        return apply_filters( 'onjob_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'onjob_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function onjob_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'onjob-pro' ),
            'off'       => esc_html__( 'Disable', 'onjob-pro' )
        );
        return apply_filters( 'onjob_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'onjob_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function onjob_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'onjob-pro' ),
            'off'       => esc_html__( 'No', 'onjob-pro' )
        );
        return apply_filters( 'onjob_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'onjob_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function onjob_pro_sortable_sections() {
        $options = onjob_pro_get_theme_options();
        $sections = array();
        if ( $options['home_layout'] == 'default-design' ) {

            $sections = array(
                'slider'                => esc_html__( 'Slider', 'onjob-pro' ),
                'search'                => esc_html__( 'Search', 'onjob-pro' ),
                'course'                => esc_html__( 'Course', 'onjob-pro' ),
                'featured_post'         => esc_html__( 'Featured Posts', 'onjob-pro' ),
                'main_post'             => esc_html__( 'Main Post', 'onjob-pro' ),
                'magazine_sport_news'   => esc_html__( 'Magazine Sport News', 'onjob-pro' ),
                'featured_job'          => esc_html__( 'Featured Jobs', 'onjob-pro' ),
                'recent_job'            => esc_html__( 'Recent Jobs', 'onjob-pro' ),
                'service'               => esc_html__( 'Service', 'onjob-pro' ),
                'about'                 => esc_html__( 'About', 'onjob-pro' ),
                'promotion'             => esc_html__( 'Promotion', 'onjob-pro' ),
                'team'                  => esc_html__( 'Team', 'onjob-pro' ),
                'video'                 => esc_html__( 'Video', 'onjob-pro' ),
                'recent_products'       => esc_html__( 'Recents Products', 'onjob-pro' ),
                'counter'               => esc_html__( 'Counter', 'onjob-pro' ),
                'gallery'               => esc_html__( 'Gallery', 'onjob-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'onjob-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'onjob-pro' ),
                'company_profile'       => esc_html__( 'Company Profiles', 'onjob-pro' ),
                'latest_post'           => esc_html__( 'Stories', 'onjob-pro' ),
                'most_viewed'           => esc_html__( 'Most Viewed', 'onjob-pro' ),
                'blog'                  => esc_html__( 'Blog', 'onjob-pro' ),
                'sponsor'               => esc_html__( 'Sponsor', 'onjob-pro' ),
            );
        }

        if ( $options['home_layout'] == 'pro-design' ) {
            $sections = array(
                'search'                => esc_html__( 'Search Section', 'onjob-pro' ),
                'featured_job'          => esc_html__( 'Featured Jobs', 'onjob-pro' ),
                'recent_job'            => esc_html__( 'Recent Jobs', 'onjob-pro' ),
                'testimonial'           => esc_html__( 'Testimonial', 'onjob-pro' ),
                'subscription'          => esc_html__( 'Subscription', 'onjob-pro' ),
                'company_profile'       => esc_html__( 'Company Profiles', 'onjob-pro' ),
                'blog'                  => esc_html__( 'Blog', 'onjob-pro' ),
                'sponsor'               => esc_html__( 'Sponsor', 'onjob-pro' ),
            );
        }

        if ( in_array($options['home_layout'], array('second-design', 'fifth-design')) ) {
            $sections = array(
                'slider'             => esc_html__( 'Slider', 'onjob-pro' ),
                'service'            => esc_html__( 'Service', 'onjob-pro' ),
                'about'              => esc_html__( 'About', 'onjob-pro' ),
                'promotion'          => esc_html__( 'Promotion', 'onjob-pro' ),
                'team'               => esc_html__( 'Team', 'onjob-pro' ),
                'video'              => esc_html__( 'Video', 'onjob-pro' ),
                'recent_products'    => esc_html__( 'Recent Products', 'onjob-pro' ),
                'counter'            => esc_html__( 'Counter', 'onjob-pro' ),
                'gallery'            => esc_html__( 'Gallery', 'onjob-pro' ),
                'testimonial'        => esc_html__( 'Testimonial', 'onjob-pro' ),
                'subscription'       => esc_html__( 'Subscription', 'onjob-pro' ),
                'blog'               => esc_html__( 'Blog', 'onjob-pro' ),
                'sponsor'            => esc_html__( 'Sponser', 'onjob-pro' ),
            );
        }

        if ( $options['home_layout'] == 'third-design' ) {
            $sections = array(
                'slider'             => esc_html__( 'Slider', 'onjob-pro' ),
                'course'             => esc_html__( 'Course', 'onjob-pro' ),
                'about'              => esc_html__( 'About', 'onjob-pro' ),
                'promotion'          => esc_html__( 'Promotion', 'onjob-pro' ),
                'service'            => esc_html__( 'Seervice', 'onjob-pro' ),
                'team'               => esc_html__( 'Team', 'onjob-pro' ),
                'video'              => esc_html__( 'Video', 'onjob-pro' ),
                'recent_products'    => esc_html__( 'Recent Products', 'onjob-pro' ),
                'counter'            => esc_html__( 'Counter', 'onjob-pro' ),
                'gallery'            => esc_html__( 'Gallery', 'onjob-pro' ),
                'testimonial'        => esc_html__( 'Testimonial', 'onjob-pro' ),
                'subscription'       => esc_html__( 'Subscription', 'onjob-pro' ),
                'blog'               => esc_html__( 'Blog', 'onjob-pro' ),
                'sponsor'            => esc_html__( 'Sponser', 'onjob-pro' ),
            );
        }

        if ( $options['home_layout'] == 'fourth-design' ) {
            $sections = array(
                'featured_post'           => esc_html__( 'Featured Posts', 'onjob-pro' ),
                'main_post'               => esc_html__( 'Main Post', 'onjob-pro' ),
                'magazine_sport_news'     => esc_html__( 'Sport News', 'onjob-pro' ),
                'latest_post'             => esc_html__( 'Latest Posts', 'onjob-pro' ),
                'most_viewed'             => esc_html__( 'Most Viewed', 'onjob-pro' ),
            );
        }
        return apply_filters( 'onjob_pro_sortable_sections', $sections );
    }
endif;



if ( ! function_exists( 'onjob_pro_promotion_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function onjob_pro_promotion_content_type() {
        $onjob_pro_promotion_content_type = array(
            'page'      => esc_html__( 'Page', 'onjob-pro' ),
            'post'      => esc_html__( 'Post', 'onjob-pro' ),
        );


        $output = apply_filters( 'onjob_pro_promotion_content_type', $onjob_pro_promotion_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'onjob_pro_typography_options' ) ) :
    function onjob_pro_typography_options(){
    $font_family_arr = array();
    $font_family_arr[''] = esc_html__( '--Default--', 'onjob-pro' );

    // Make the request
    $request = wp_remote_get( get_theme_file_uri( 'assets/webfonts.json' ) );

    if( is_wp_error( $request ) ) {
        return false; // Bail early
    }
     // Retrieve the data
    $body = wp_remote_retrieve_body( $request );
    $data = json_decode( $body );
    if ( ! empty( $data ) ) {
        foreach ( $data->items as $items => $fonts ) {
            $family_str_arr = explode( ' ', $fonts->family );
            $family_value = implode( '+', $family_str_arr );
            $font_family_arr[ $family_value ] = $fonts->family;
        }
    }

    return $font_family_arr;
}
endif;

if ( ! function_exists( 'onjob_pro_featured_job_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function onjob_pro_featured_job_content_type() {
        $onjob_pro_featured_job_content_type = array(
            'post'              => esc_html__( 'Posts', 'onjob-pro' ),
            'page'              => esc_html__( 'Pages', 'onjob-pro' ),
            'category'          => esc_html__( 'Category', 'onjob-pro' ),

        );

        if ( class_exists( 'WP_Job_Manager' ) ) {
            $onjob_pro_featured_job_content_type = array_merge( $onjob_pro_featured_job_content_type, array(
                'job_listing'               => esc_html__( 'Jobs', 'onjob-pro' ),
                'job_listing_category'      => esc_html__( 'Job Categories', 'onjob-pro' ),
            ) );
        }

        $output = apply_filters( 'onjob_pro_featured_job_content_type', $onjob_pro_featured_job_content_type );

        return $output;
    }
endif;

if ( ! function_exists( 'onjob_pro_company_profile_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function onjob_pro_company_profile_content_type() {
        $onjob_pro_company_profile_content_type = array(
            'post'              => esc_html__( 'Posts', 'onjob-pro' ),
            'page'              => esc_html__( 'Pages', 'onjob-pro' ),
            'category'          => esc_html__( 'Category', 'onjob-pro' ),

        );

        if ( class_exists( 'WP_Job_Manager' ) ) {
            $onjob_pro_company_profile_content_type = array_merge( $onjob_pro_company_profile_content_type, array(
                'job_listing'               => esc_html__( 'Jobs', 'onjob-pro' ),
                'job_listing_category'      => esc_html__( 'Job Categories', 'onjob-pro' ),
            ) );
        }

        $output = apply_filters( 'onjob_pro_company_profile_content_type', $onjob_pro_company_profile_content_type );

        return $output;
    }
endif;
