<?php
/**
 * Banner section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Onjob Pro 1.0.0
    */
    function onjob_pro_add_about_section() {
    	$options = onjob_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'onjob_pro_section_status', true, 'about_section_enable' ) ;

        if ( in_array( $options['home_layout'], array( 'pro-design', 'fourth-design', ) ) ) {
            $about_enable = false;
        }
        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render about section now.
        onjob_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Onjob Pro 1.0.0
    * @param array $input about section details.
    */
    function onjob_pro_get_about_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        $about_content_type  = get_theme_mod( 'onjob_pro_theme_options_about_content_type', $options['about_content_type'] );
        
        $content = array();
        switch ( $about_content_type ) {
            case 'page':
                $page_id = '';
                if ( ! empty( $options['about_content_page'] ) )
                    $page_id = isset($options['about_content_page']) ? $options['about_content_page'] : '' ;
                $args = array(
                    'post_type'             => 'page',
                    'p'                     =>  absint( $page_id ),
                    'ignore_sticky_posts'   => true,
                    );
                break;

            case 'post':
                $post_id = '';
                if ( ! empty( $options['about_content_post'] ) )
                    $post_id = isset($options['about_content_post'])?$options['about_content_post']:'';
                $args = array(
                    'post_type'             => 'post',
                    'p'                     => absint( $post_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;

            case 'category':
                $cat_id = isset( $options['about_category'] ) ? $options['about_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
                break;
            case 'custom':
                $page_post['excerpt']   = isset($options['about_custom_content']) ? $options['about_custom_content'] : '';
                $page_post['title']     = isset($options['about_custom_title'])? $options['about_custom_title']: '';
                $page_post['url']       = isset($options['about_us_btn_url']) ? $options['about_us_btn_url']: '#';
                $page_post['image']     = !empty($options['about_custom_image']) ? $options['about_custom_image']: get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                array_push( $content, $page_post );
                return $content;
            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['excerpt']   = onjob_pro_trim_content(40);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink( );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'onjob_pro_filter_about_section_details', 'onjob_pro_get_about_section_details' );


if ( ! function_exists( 'onjob_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_about_section( $content_details = array() ) {
        $options        = onjob_pro_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php $content = $content_details[0];?>

            <div id="about-section" class="relative page-section same-background">
                <div class="wrapper">
                    <article class="has-post-thumbnail">
                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['image']); ?>"><img src="<?php echo esc_url( $content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <div class="section-header">
                                <p class="section-subtitle"><?php echo esc_html($options['about_section_title']); ?></p>
                                <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                            </div><!-- .section-header -->

                            <div class="entry-content">
                                <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->

                            <?php if(!empty($options['about_btn_txt'])) :?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html($options['about_btn_txt']); ?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- about-section -->
     
    <?php
    }    
endif; 
