<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_blog_section() {
        $options = onjob_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'onjob_pro_section_status', true, 'blog_section_enable' );

        if ( in_array( $options['home_layout'], array( 'fourth-design') ) ) {
            $blog_enable = false;
        }
        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render blog section now.
        onjob_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input blog section details.
    */
    function onjob_pro_get_blog_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3;
        
        
        $content = array();
        switch ( $blog_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $blog_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $blog_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = onjob_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'onjob_pro_filter_blog_section_details', 'onjob_pro_get_blog_section_details' );


if ( ! function_exists( 'onjob_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_blog_section( $content_details = array() ) {
        $options                = onjob_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="latest-posts" class="relative page-section <?php if($options['home_layout'] != 'pro-design') echo 'section-lite'; ?>">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html($options['blog_title']); ?></h2>
                </div><!-- .section-header -->

                <div class="archive-blog-wrapper col-3 clear">
                <?php foreach ($content_details as $content): ?>

                    <article>
                        <div class="post-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']);?>"><img src="<?php echo esc_url($content['image']);?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-meta">
                                    <?php onjob_pro_posted_on($content['id']); ?>
                                    
                                    <span class="cat-links">
                                        <?php the_category(' ', ' ', $content['id']); ?>
                                    </span>
                                </div><!-- .entry-meta -->
                            </div><!-- .entry-container -->
                        </div><!-- .post-wrapper -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php if(!empty($options['blog_read_more_btn_label']) && !empty($options['blog_read_more_btn_url'])): ?>
                    <div class="show-all">
                        <a href="<?php echo esc_url($options['blog_read_more_btn_url']); ?>" class="btn"><?php echo esc_html($options['blog_read_more_btn_label']); ?></a>
                    </div><!-- .show-all -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->

<?php }
endif;  ?>