<?php
/**
 * Company Profile section
 *
 * This is the template for the content of company_profile section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_company_profile_section' ) ) :
    /**
    * Add company_profile section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_company_profile_section() {
    	$options = onjob_pro_get_theme_options();
        // Check if Company Profile is enabled on frontpage
        $company_profile_enable = apply_filters( 'onjob_pro_section_status', true, 'company_profile_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'pro-design' ) ) ) {
            $company_profile_enable = false;
        }

        if ( true !== $company_profile_enable ) {
            return false;
        }
        // Get Company Profile section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_company_profile_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Company Profile section now.
        onjob_pro_render_company_profile_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_company_profile_section_details' ) ) :
    /**
    * Company Profile section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input Company Profile section details.
    */
    function onjob_pro_get_company_profile_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        $company_profile_count = ! empty( $options['company_profile_count'] ) ? $options['company_profile_count'] : 3;
        $company_profile_content_type = ! empty( $options['company_profile_content_type'] ) ? $options['company_profile_content_type'] : '';
        
        $content = array();
        switch ( $company_profile_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $company_profile_count; $i++ ) {
                    if ( ! empty( $options['company_profile_content_page_' . $i] ) ) :
                        $page_ids[] = $options['company_profile_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $company_profile_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $company_profile_count; $i++ ) {
                    if ( ! empty( $options['company_profile_content_post_' . $i] ) ) :
                        $post_ids[] = $options['company_profile_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $company_profile_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                );                    
            break;

            case 'job_listing':
                $post_ids = array();

                for ( $i = 1; $i <= $company_profile_count; $i++ ) {
                    if ( ! empty( $options['company_profile_content_job_' . $i] ) ) :
                        $post_ids[] = $options['company_profile_content_job_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'job_listing',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $company_profile_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['company_profile_content_category'] ) ? $options['company_profile_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $company_profile_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                );                    
            break;

            case 'job_listing_category':
                $cat_id = ! empty( $options['company_profile_content_job_listing_category'] ) ? $options['company_profile_content_job_listing_category'] : '';
                $args = array(
                    'post_type'         => 'job_listing',
                    'posts_per_page'    => absint( $company_profile_count ),
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'job_listing_category',
                            'field'    => 'term_id',
                            'terms'    => $cat_id ,
                        ),
                    ),
                    'ignore_sticky_posts'   => true,
                );                    

            default:
            break;
        }
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']        = get_the_ID();
                    $page_post['excerpt']   = onjob_pro_trim_content( 20);
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// Company Profile section content details.
add_filter( 'onjob_pro_filter_company_profile_section_details', 'onjob_pro_get_company_profile_section_details' );


if ( ! function_exists( 'onjob_pro_render_company_profile_section' ) ) :
  /**
   * Start Company Profile section
   *
   * @return string Company Profile content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_company_profile_section( $content_details = array() ) {
        $options = onjob_pro_get_theme_options();
        $company_profile_content_type = ! empty( $options['company_profile_content_type'] ) ? $options['company_profile_content_type'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="company-profiles" class="relative page-section">
                <div class="wrapper">
                    <div class="section-header-wrapper">
                        <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html($options['company_profile_sub_title']); ?></p>
                            <h2 class="section-title"><?php echo esc_html($options['company_profile_title']); ?></h2>
                        </div><!-- .section-header -->

                        <?php if(!empty($options['company_profile_btn_txt']) && !empty($options['company_profile_btn_url'])) :?>
                            <div class="show-all">
                                <a href="<?php echo esc_url($options['company_profile_btn_url']); ?>" class="btn"><?php echo esc_html($options['company_profile_btn_txt']); ?></a>
                            </div><!-- .show-all -->
                        <?php endif; ?>

                    </div><!-- .section-header-wrapper -->

                    <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $content ) :   ?>

                        <article>
                            <div class="item-wrapper">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                    
                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->

                                <?php if(class_exists('WP_Job_Manager') ): 
                                $taxonomy = ($company_profile_content_type == 'job_listing_category' || $company_profile_content_type == 'job_listing' ) ? 'job_listing_category' : 'category'; ?>
                                <div class="entry-meta-wrapper">
                                        <div class="entry-meta">
                                            <span class="cat-links">
                                            <?php if(taxonomy_exists($taxonomy) && $company_profile_content_type != 'page'): ?>
                                                <?php  $terms = get_the_terms($content['id'], $taxonomy); ?>
                                                    <a href="<?php echo esc_url(get_term_link($terms[0]->slug, $taxonomy)); ?>"><?php echo $terms[0]->name; ?></a>
                                                </span><!-- .cat-links -->

                                                <?php if(in_array($company_profile_content_type, ['job_listing', 'job_listing_category']))
                                                    echo '<span class="location"><a href="#">'. get_the_job_location( $content['id'] ).'</a></span>'; ?>

                                            </div><!-- .entry-meta -->
                                            <span class="available-jobs"><a href="#"><?php echo sprintf( esc_html__('%d Jobs', 'onjob-pro'), $terms[0]->count); ?></a></span>
                                        <?php endif; ?>
                                    </div><!-- .entry-meta-wrapper -->
                                <?php endif; ?>
                            </div><!-- .item-wrapper -->
                        </article>
                        <?php endforeach; ?>
                    </div><!-- .section-content -->

                    <?php if(!empty($options['company_profile_btn_txt']) && !empty($options['company_profile_btn_url'])) :?>
                        <div class="show-all responsive-btn">
                            <a href="<?php echo esc_url($options['company_profile_btn_url']); ?>" class="btn"><?php echo esc_html($options['company_profile_btn_txt']); ?></a>
                        </div><!-- .show-all -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #company-profiles -->
<?php 
    }
endif;