<?php
/**
 * counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_counter_section() {
        $options = onjob_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'onjob_pro_section_status', true, 'counter_section_enable' );

        if ( in_array( $options['home_layout'], array( 'pro-design', 'fourth-design' ) ) ) {
            $counter_enable = false;
        }

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        onjob_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'onjob_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_counter_section() {
        $options = onjob_pro_get_theme_options();
        $image   = empty( $options['counter_image'] ) ? '' : $options['counter_image'] ;
        $counter_count = ! empty( $options['counter_count'] ) ? $options['counter_count'] : 4;

        $contents = array();
        for( $i= 1; $i <= absint( $counter_count ); $i++ ){
            $page_post['title']     = empty( $options['counter_title_'.$i] ) ? '' : $options['counter_title_'.$i];
            $page_post['icon']      = empty( $options['counter_icon_'.$i] ) ? '' : $options['counter_icon_'.$i];
            $page_post['number']    = empty( $options['counter_number_'.$i] ) ? '' : $options['counter_number_'.$i];

            if(!empty($page_post['title']) || !empty($page_post['percent']) || !empty($page_post['icon']) || !empty($page_post['number']))  array_push( $contents, $page_post );
        } ?>
        

            <div id="counter-section" class="relative page-section" style="background-image: url('<?php echo esc_url( $image ) ; ?>');">
                <div class="overlay"></div>
                <div class="wrapper">
                   <?php if(!empty($contents)): ?>
                        <div class="section-content col-4 clear">
                        <?php foreach ( $contents as $content ): ?>
                            <article>
                                <div class="counter-item">
                                    <div class="counter-icon">
                                        <i class="fa <?php echo esc_attr($content['icon']); ?>"></i>
                                    </div>
                                    <h2 class="counter-value"><?php echo esc_html( $content['number'] ); ?></h2>
                                    <h3 class="counter-title"><?php echo esc_html( $content['title'] ); ?></h3>
                                </div>
                            </article>
                        <?php endforeach; ?>
                        </div><!-- .section-content -->
                    <?php endif; ?>
                </div><!-- .wrapper -->
            </div><!-- #counter-section -->

    <?php }
endif;
