<?php
/**
 * Course section
 *
 * This is the template for the content of course section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_course_section' ) ) :
    /**
    * Add course section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_course_section() {
    	$options = onjob_pro_get_theme_options();
        // Check if course is enabled on frontpage
        $course_enable = apply_filters( 'onjob_pro_section_status', true, 'course_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design','third-design') ) ) {
            $course_enable = false;
        }

        if ( true !== $course_enable ) {
            return false;
        }
        // Get course section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_course_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render course section now.
        onjob_pro_render_course_section( $section_details );
}

endif;

if ( ! function_exists( 'onjob_pro_get_course_section_details' ) ) :
    /**
    * course section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input course section details.
    */
    function onjob_pro_get_course_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        $course_content_type    = $options['course_content_type'];
        $course_count           = ! empty( $options['course_count'] ) ? $options['course_count'] : 4;
        
        $content = array();
        switch ( $course_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_page_' . $i] ) )
                        $page_ids[] = $options['course_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $course_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $course_count; $i++ ) {
                    if ( ! empty( $options['course_content_post_' . $i] ) )
                        $post_ids[] = $options['course_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $course_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['course_category'] ) ? $options['course_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $course_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = onjob_pro_trim_content($options['course_excerpt_length']);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri().'/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// course section content details.
add_filter( 'onjob_pro_filter_course_section_details', 'onjob_pro_get_course_section_details' );


if ( ! function_exists( 'onjob_pro_render_course_section' ) ) :
  /**
   * Start course section
   *
   * @return string course content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_course_section( $content_details = array() ) {
        $options = onjob_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="course-section" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($options['course_sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html($options['course_title']); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $content ) : ?>
                    <article>
                        <div class="course-item">
                            <div class="entry-container">
                                <div class="featured-image">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['url'] ); ?>"></a>
                                </div><!-- .featured-image -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->
                                
                                <?php if(!empty($options['course_btn_txt'])): ?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url($content['url']); ?>"><i class="fa fa-plus"></i><?php echo esc_html($options['course_btn_txt']); ?></a>
                                </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .course-item -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .col-3 -->
            </div><!-- .wrapper -->
        </div>

<?php
    }    
endif;