<?php
/**
 * Featured Jobs section
 *
 * This is the template for the content of featured_job section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_featured_job_section' ) ) :
    /**
    * Add featured_job section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_featured_job_section() {
        $options = onjob_pro_get_theme_options();
        // Check if featured_job is enabled on frontpage
        $featured_job_enable = apply_filters( 'onjob_pro_section_status', true, 'featured_job_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design','pro-design' ) ) ) {
            $featured_job_enable = false;
        }

        if ( true !== $featured_job_enable ) {
            return false;
        }
        // Get featured_job section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_featured_job_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured_job section now.
        onjob_pro_render_featured_job_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_featured_job_section_details' ) ) :
    /**
    * featured_job section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input featured_job section details.
    */
    function onjob_pro_get_featured_job_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        
        $featured_job_content_type = ! empty( $options['featured_job_content_type'] ) ? $options['featured_job_content_type'] : 'category';
        $featured_job_count = ! empty( $options['featured_job_count'] ) ? $options['featured_job_count'] : 5;
        
        $content = array();
        switch ( $featured_job_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 0; $i <= $featured_job_count; $i++ ) {
                    if ( ! empty( $options['featured_job_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_job_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_job_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 0; $i < $featured_job_count; $i++ ) {
                    if ( ! empty( $options['featured_job_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_job_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $featured_job_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'job_listing':
                $post_ids = array();

                for ( $i = 0; $i < $featured_job_count; $i++ ) {
                    if ( ! empty( $options['featured_job_content_job_listing_' . $i] ) ) :
                        $post_ids[] = $options['featured_job_content_job_listing_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'             => 'job_listing',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $featured_job_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_ids = array();

                for ( $i = 0; $i < $featured_job_count; $i++ ) {
                    if ( ! empty( $options['featured_job_content_category_' . $i] ) ) :
                        $cat_ids[] = $options['featured_job_content_category_' . $i];
                    endif;
                }
                $args = array(
                    'taxonomy'             => 'category',
                    'terms'                =>  $cat_ids ,
                );    

            break;

            case 'job_listing_category':
                $cat_ids = array();
                
                for ( $i = 0; $i < $featured_job_count; $i++ ) {
                    if ( ! empty( $options['featured_job_content_job_listing_category_' . $i] ) ) :
                        $cat_ids[] = $options['featured_job_content_job_listing_category_' . $i];
                    endif;
                }
                $args = array(
                    'taxonomy'             => 'job_listing_category',
                    'terms'                =>  $cat_ids ,
                );      
            break;

      
            default:
            break;
        }
        // Run The Loop.
        if(!in_array($featured_job_content_type, ['job_listing_category', 'category'])):
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = onjob_pro_trim_content(15);
                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        else:

            if(taxonomy_exists($args['taxonomy'])){
                foreach($args['terms'] as $tax_id):
                    $term = get_term($tax_id, $args['taxonomy']);
                    if(!is_wp_error($term) && $term != NULL ){
                        $page_post['title']     = $term->name;
                        $page_post['id']        = $term->term_id;
                        $page_post['url']       = get_term_link($term->slug, $args['taxonomy']);
                        $page_post['excerpt']   = onjob_pro_trim_description(15, $term);
        
                        array_push( $content, $page_post );
                    }
                endforeach;
            }
        endif;

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured_job section content details.
add_filter( 'onjob_pro_filter_featured_job_section_details', 'onjob_pro_get_featured_job_section_details' );


if ( ! function_exists( 'onjob_pro_render_featured_job_section' ) ) :
  /**
   * Start featured_job section
   *
   * @return string featured_job content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_featured_job_section( $content_details = array() ) {
        $options                = onjob_pro_get_theme_options(); ?>

        <div id="featured-jobs" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($options['featured_job_sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html($options['featured_job_title']); ?></h2>
                </div><!-- .section-header -->
            </div><!-- .wrapper -->

            <div class="career-slider wrapper" data-slick='{"slidesToShow": 4, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows": true, "autoplay": true, "draggable": true }'>
                <?php foreach($content_details as $i=>$content): ?>
                <article>
                    <div class="item-wrapper">
                        <div class="icon-wrapper">
                            <a href="<?php echo esc_url($content['url']); ?>"><i class="fa <?php echo esc_attr( !empty( $options['featured_job_icon_' . (absint($i))] ) ? $options['featured_job_icon_' . (absint($i))] : 'fa-briefcase' ); ?>"></i></a>
                        </div><!-- .icon-wrapper -->

                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                        </header>

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['excerpt']); ?></p>
                        </div><!-- .entry-content -->
                    </div><!-- .item-wrapper -->
                </article>
                <?php endforeach; ?>
            </div><!-- .career-slider -->
        </div><!-- #featured-jobs -->
       
<?php }
endif;  ?>