<?php
/**
 * Blog section
 *
 * This is the template for the content of magazine_sport_news section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_magazine_sport_news_section' ) ) :
    /**
    * Add magazine_sport_news section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_magazine_sport_news_section() {
        $options = onjob_pro_get_theme_options();
        // Check if magazine_sport_news is enabled on frontpage
        $magazine_sport_news_enable = apply_filters( 'onjob_pro_section_status', true, 'magazine_sport_news_section_enable' );

        if ( !in_array( $options['home_layout'], array( 'default-design', 'fourth-design') ) ) {
            $magazine_sport_news_enable = false;
        }

        if ( true !== $magazine_sport_news_enable ) {
            return false;
        }
        // Get magazine_sport_news section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_magazine_sport_news_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render magazine_sport_news section now.
        onjob_pro_render_magazine_sport_news_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_magazine_sport_news_section_details' ) ) :
    /**
    * magazine_sport_news section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input magazine_sport_news section details.
    */
    function onjob_pro_get_magazine_sport_news_section_details( $input ) {
        $options = onjob_pro_get_theme_options();

        // Content type.
        $magazine_sport_news_content_type  = $options['magazine_sport_news_content_type'];
        $magazine_sport_news_count = ! empty( $options['magazine_sport_news_count'] ) ? $options['magazine_sport_news_count'] : 4;
        
        
        $content = array();
        switch ( $magazine_sport_news_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $magazine_sport_news_count; $i++ ) {
                    if ( ! empty( $options['magazine_sport_news_content_page_' . $i] ) )
                        $page_ids[] = $options['magazine_sport_news_content_page_' . $i];
                }
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $magazine_sport_news_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $magazine_sport_news_count; $i++ ) {
                    if ( ! empty( $options['magazine_sport_news_content_post_' . $i] ) )
                        $post_ids[] = $options['magazine_sport_news_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'             => 'post',
                    'post__in'              => ( array ) $post_ids,
                    'posts_per_page'        => absint( $magazine_sport_news_count ),
                    'orderby'               => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['magazine_sport_news_content_category'] ) ? $options['magazine_sport_news_content_category'] : '';
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $magazine_sport_news_count ),
                    'cat'                   => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['magazine_sport_news_category_exclude'] ) ? $options['magazine_sport_news_category_exclude'] : array();
                $args = array(
                    'post_type'             => 'post',
                    'posts_per_page'        => absint( $magazine_sport_news_count ),
                    'category__not_in'      => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = onjob_pro_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// magazine_sport_news section content details.
add_filter( 'onjob_pro_filter_magazine_sport_news_section_details', 'onjob_pro_get_magazine_sport_news_section_details' );


if ( ! function_exists( 'onjob_pro_render_magazine_sport_news_section' ) ) :
  /**
   * Start magazine_sport_news section
   *
   * @return string magazine_sport_news content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_magazine_sport_news_section( $content_details = array() ) {
        $options                = onjob_pro_get_theme_options();
        $magazine_sport_news_content_type  = $options['magazine_sport_news_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="magazine-sports-news" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html($options['magazine_sport_news_section_title']); ?></h2>
                </div><!-- .section-header -->

                <div class="section-content col-4 clear">
                    <?php foreach($content_details as $content) : ?>
                    <article class="has-post-thumbnail">
                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <a href="<?php echo esc_url($content['image']) ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']) ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">

                            <?php if($magazine_sport_news_content_type !== 'page'): ?>
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php echo get_the_category_list(' ', ' ', $content['id']); ?>
                                </span><!-- .cat-links -->
                            </div><!-- .entry-meta -->
                            <?php endif; ?>


                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                            </header>

                            <div class="entry-meta author-posted-on">
                                <?php echo onjob_pro_author($content['id']); onjob_pro_posted_on(); ?>
                            </div><!-- .entry-meta -->

                            <div class="entry-content">
                                <p><?php echo wp_kses_post($content['excerpt']);?></p>
                            </div><!-- .entry-content -->
                        </div><!-- .entry-container -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

<?php  }
endif;  ?>