<?php
/**
 * Subscription section
 *
 * This is the template for the content of subscription section
 *
 * @package Theme Palace
 * @subpackage Onjob Pro
 * @since Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_subscription_section' ) ) :
    /**
    * Add subscription section
    *
    *@since Onjob Pro 1.0.0
    */
    function onjob_pro_add_subscription_section() {
        $options = onjob_pro_get_theme_options();
        if ( ! class_exists( 'Jetpack' ) ) {
            return;
        } elseif ( class_exists( 'Jetpack' ) ) {
            if ( ! Jetpack::is_module_active( 'subscriptions' ) )
                return;
        }

        // Check if subscription is enabled on frontpage
        $subscription_enable = apply_filters( 'onjob_pro_section_status', true, 'subscription_section_enable' );

        if ( true !== $subscription_enable ) {
            return false;
        }
        // Render subscription section now.
        onjob_pro_render_subscription_section();
    }
endif;

if ( ! function_exists( 'onjob_pro_render_subscription_section' ) ) :
  /**
   * Start subscription section
   *
   * @return string subscription content
   * @since Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_subscription_section() {
        $options = onjob_pro_get_theme_options(); 
        $subscription_bg_image = !empty($options['subscription_bg_image']) ? $options['subscription_bg_image'] : ''; ?>
     
        <div id="subscribe-section" class="relative page-section">
            <div class="wrapper">
                <div class="section-header">
                    <?php 
                    if(!empty($options['subscription_section_title'])) echo '<h2 class="section-title">' .esc_html($options['subscription_section_title']). '</h2>';
                    if(!empty($options['subscription_section_description'])) echo '<p class="section-subtitle">' .wp_kses_post($options['subscription_section_description']). '</p>'; ?>

                </div><!-- .section-header -->

                <div class="subscribe-form-wrapper" style="background-image: url('<?php echo esc_url($subscription_bg_image); ?>');">
                <div class="subscribe-form-wrapper">
                <?php
                    $subscription_shortcode = '[jetpack_subscription_form title="" subscribe_button="' . esc_html( $options['subscription_section_btn_txt'] ) . '" subscribe_text="'. esc_html( $options['subscription_section_sub_title'] )  .'" show_subscribers_total="0"]';
                    echo do_shortcode( wp_kses_post( $subscription_shortcode ) );  
                    if(!empty($options['subscription_section_policy'])) echo '<p id="policy"><label>' .wp_kses_post($options['subscription_section_policy']). '</label></p>';
                    ?>
                    
                </div>
                </div><!-- .subscribe-form-wrapper -->
            </div><!-- .wrapper -->
        </div>
    <?php
    }
endif; ?>
