<?php
/**
 * Blog section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage  Onjob Pro
 * @since  Onjob Pro 1.0.0
 */
if ( ! function_exists( 'onjob_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since  Onjob Pro 1.0.0
    */
    function onjob_pro_add_video_section() {
        $options = onjob_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'onjob_pro_section_status', true, 'video_section_enable' );

        if ( in_array( $options['home_layout'], array( 'pro-design', 'fourth-design') ) ) {
            $video_enable = false;
        }

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'onjob_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render video section now.
        onjob_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'onjob_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since  Onjob Pro 1.0.0
    * @param array $input video section details.
    */
    function onjob_pro_get_video_section_details( $input ) {
        $options = onjob_pro_get_theme_options();
        $content = array();

        $content['sub_title']     = empty( $options['video_section_sub_title'] ) ? '' : $options['video_section_sub_title'];
        $content['title']      = empty( $options['video_section_title'] ) ? '' : $options['video_section_title'];
        $content['bg_image']    = empty( $options['video_bg_image'] ) ? '' : $options['video_bg_image'];
        $content['video_id']    = empty( $options['video_id'] ) ? '' : $options['video_id'];


        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'onjob_pro_filter_video_section_details', 'onjob_pro_get_video_section_details' );


if ( ! function_exists( 'onjob_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since  Onjob Pro 1.0.0
   *
   */
   function onjob_pro_render_video_section( $content_details = array() ) {
        $options                = onjob_pro_get_theme_options();
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="video-section" class="relative page-section" style="background-image: url('<?php echo esc_html($content_details['bg_image']); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($content_details['sub_title']); ?></p>
                    <h2 class="section-title"><?php echo esc_html($content_details['title']); ?></h2>
                </div><!-- .section-header -->

                <?php if(!empty($content_details['video_id'])) :?>
                    <div class="video-wrapper">
                        <iframe width="900" height="506" src="https://www.youtube.com/embed/<?php echo esc_attr( $content_details['video_id'] ); ?>" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe>
                    </div><!-- .video-wrapper -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #video-section -->
   
    <?php }
endif;  ?>
